@@ -7,7 +7,7 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
@@ -131,10 +131,21 @@ char *get_filename(int file_no)
 char *get_path(int file_no)
 {
    GdsFile *file;
+   gchar *path;
+   gchar *tmp;
+
    file = (GdsFile *)g_list_nth_data(files_list, file_no);
    g_return_val_if_fail(file != NULL, NULL);
    g_return_val_if_fail(GDS_IS_FILE(file), NULL);
-   return(get_path_from_filename(file->filename));
+   path = get_path_from_filename(file->filename);
+   if((tmp = strstr(path, "://")))
+   {
+      tmp += 3;
+      tmp = g_strdup(tmp);
+      g_free(path);
+      path = tmp;
+   }
+   return(path);
 }
 
 char *get_file(int file_no)
@@ -688,7 +699,7 @@ void add_syntax_entry(char *name, char *start, char *end, char *color, char *ccl
    start_string = g_str_replace_bad_chars(start);
    end_string = g_str_replace_bad_chars(end);
    info = get_highlight_info(color, cclass);
-   syntax_list = gds_editor_syntax_entry_new(syntax_list, name, start_string, end_string, info->color, NULL, info->font, info->flags, info->type);
+   syntax_list = gtk_extext_syntax_entry_new(syntax_list, name, start_string, end_string, info->color, NULL, info->font, info->flags, GINT_TO_POINTER(info->type));
    g_free(start_string);
    g_free(end_string);
    g_free(info);
@@ -701,25 +712,22 @@ void add_pattern_entry(char *name, char *words, char *color, char *cclass)
    if(!parsing_language) return;
    words_string = g_str_replace_bad_chars(words);
    info = get_highlight_info(color, cclass);
-   pattern_list = gds_editor_pattern_entry_new(pattern_list, name, words_string, info->color, NULL, info->font, info->flags, info->type);
+   pattern_list = gtk_extext_pattern_entry_new(pattern_list, name, words_string, info->color, NULL, info->font, info->flags, GINT_TO_POINTER(info->type));
    g_free(words_string);
    g_free(info);
 }
 
-void add_embedded_entry(char *name, char *start, char *words, char *end, char *color, char *cclass)
+void add_embedded_entry(char *name, char *outside, char *inside, char *color, char *cclass)
 {
-   gchar *start_string;
-   gchar *words_string;
-   gchar *end_string;
+   gchar *outside_string;
+   gchar *inside_string;
    HighlightInfo *info;
    if(!parsing_language) return;
-   start_string = g_str_replace_bad_chars(start);
-   words_string = g_str_replace_bad_chars(words);
-   end_string = g_str_replace_bad_chars(end);
+   outside_string = g_str_replace_bad_chars(outside);
+   inside_string = g_str_replace_bad_chars(inside);
    info = get_highlight_info(color, cclass);
-   embedded_list = gds_editor_embedded_entry_new(embedded_list, name, start_string, end_string, words_string, info->color, NULL, info->font, info->flags, info->type);
-   g_free(start_string);
-   g_free(words_string);
-   g_free(end_string);
+   embedded_list = gtk_extext_embedded_entry_new(embedded_list, name, outside_string, inside_string, info->color, NULL, info->font, info->flags, GINT_TO_POINTER(info->type));
+   g_free(outside_string);
+   g_free(inside_string);
    g_free(info);
 }
