@@ -7,7 +7,7 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
@@ -104,7 +104,7 @@ int replace_all_in(int file_no, char *search_text, char *replacer);
 
 void add_syntax_entry(char *name, char *start, char *end, char *color, char *cclass);
 void add_pattern_entry(char *name, char *words, char *color, char *cclass);
-void add_embedded_entry(char *name, char *start, char *words, char *end, char *color, char *cclass);
+void add_embedded_entry(char *name, char *outside, char *inside, char *color, char *cclass);
 
 #ifdef __cplusplus
 }
