@@ -7,7 +7,7 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
@@ -35,7 +35,8 @@ void save_error(gchar *filename);
 void read_only(gchar *filename);
 void create_error(gchar *filename);
 void generic_dialog_with_text(gchar *text);
-
+void error_dialog_with_text(const gchar *text);
+gint bad_uri_data_dialog(const gchar *missing);
 #ifdef __cplusplus
 }
 #endif
