@@ -7,20 +7,23 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ifndef _DRAG_N_DROP_
-#define _DRAG_N_DROP_
+#ifndef _DRAG_N_DROP_H_
+#define _DRAG_N_DROP_H_
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
+#include "declarations.h"
+#include "main.h"
+
 void init_dnd(void);
 
 #ifdef __cplusplus
