@@ -7,7 +7,7 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
@@ -30,6 +30,20 @@ void get_prefs(void)
    build_defaults();
    if(!gnome_config_has_section("/" PACKAGE "/General")) save_defaults();
 
+   general_preferences.full_filenames_title = gnome_config_get_int("/" PACKAGE "/File Settings/full_filenames_title=0");
+   general_preferences.full_filenames = gnome_config_get_int("/" PACKAGE "/File Settings/full_filenames=0");
+   general_preferences.async_xfer = gnome_config_get_int("/" PACKAGE "/File Settings/async_xfer=0");
+   general_preferences.close_all = gnome_config_get_int("/" PACKAGE "/File Settings/close_all=1");
+   general_preferences.untitled = gnome_config_get_int("/" PACKAGE "/File Settings/untitled=1");
+   general_preferences.show_dots = gnome_config_get_int("/" PACKAGE "/File Settings/show_dots=1");
+   general_preferences.show_details = gnome_config_get_int("/" PACKAGE "/File Settings/show_details=0");
+   general_preferences.draw_numbers = gnome_config_get_int("/" PACKAGE "/File Settings/draw_numbers=0");
+   general_preferences.draw_pixmaps = gnome_config_get_int("/" PACKAGE "/File Settings/draw_pixmaps=0");
+   general_preferences.cursor_blink = gnome_config_get_int("/" PACKAGE "/File Settings/cursor_blink=1");
+   general_preferences.full_selection = gnome_config_get_int("/" PACKAGE "/File Settings/full_selection=1");
+   general_preferences.toolbar_style = gnome_config_get_int("/" PACKAGE "/General/toolbar_style=0");
+   general_preferences.notebook_tab_position = gnome_config_get_int("/" PACKAGE "/General/tab_position=0");
+
    text = gnome_config_get_string("/" PACKAGE "/General/default_dir");
    strcpy(general_preferences.default_dir, text);
    g_free(text);
@@ -41,15 +55,13 @@ void get_prefs(void)
    general_preferences.save_toolbars = gnome_config_get_int("/" PACKAGE "/General/save_toolbars=1");
    general_preferences.save_session = gnome_config_get_int("/" PACKAGE "/General/save_session=1");
    general_preferences.open_session = gnome_config_get_int("/" PACKAGE "/General/open_session=1");
-
+   general_preferences.auto_save = gnome_config_get_int("/" PACKAGE "/General/auto_save=1");
+   general_preferences.history = gnome_config_get_int("/" PACKAGE "/General/history_items=15");
+   general_preferences.undo_max = gnome_config_get_int("/" PACKAGE "/General/undo_max=20");
    text = gnome_config_get_string("/" PACKAGE "/General/session_name");
    if(text && general_preferences.open_session) { g_free(session_file); session_file = text; }
    else g_free(text);
 
-   general_preferences.history = gnome_config_get_int("/" PACKAGE "/General/history_items=15");
-   general_preferences.undo_max = gnome_config_get_int("/" PACKAGE "/General/undo_max=20");
-   general_preferences.notebook_tab_position = gnome_config_get_int("/" PACKAGE "/General/tab_position=0");
-
    text = gnome_config_get_string("/" PACKAGE "/Build/terminal");
    if(text && strlen(text) > 0)
    {
@@ -76,6 +88,34 @@ void get_prefs(void)
       g_free(text);
    }
 
+   general_preferences.bracketmatch = gnome_config_get_int("/" PACKAGE "/File Settings/bracketmatch=1");
+   general_preferences.select_line = gnome_config_get_int("/" PACKAGE "/File Settings/select_line=0");
+   general_preferences.syntax = gnome_config_get_int("/" PACKAGE "/File Settings/syntax=1");
+   general_preferences.auto_indent = gnome_config_get_int("/" PACKAGE "/File Settings/auto_indent=1");
+   general_preferences.tab_stops = gnome_config_get_int("/" PACKAGE "/File Settings/tab_stops=1");
+   general_preferences.use_spaces = gnome_config_get_int("/" PACKAGE "/File Settings/use_spaces=0");
+   general_preferences.spaces = gnome_config_get_int("/" PACKAGE "/File Settings/spaces=4");
+
+   general_preferences.geometry = gnome_config_get_int("/" PACKAGE "/Geometry/use");
+   general_preferences.x = gnome_config_get_int("/" PACKAGE "/Geometry/x");
+   general_preferences.y = gnome_config_get_int("/" PACKAGE "/Geometry/y");
+   general_preferences.w = gnome_config_get_int("/" PACKAGE "/Geometry/w");
+   general_preferences.h = gnome_config_get_int("/" PACKAGE "/Geometry/h");
+
+   text = gnome_config_get_string("/" PACKAGE "/Print Settings/print_font");
+   if(text && strlen(text) > 0)
+   {
+      strcpy(general_preferences.print_font, text);
+      g_free(text);
+   }
+
+   general_preferences.print_landscape = gnome_config_get_int("/" PACKAGE "/Print Settings/print_landscape=0");
+   general_preferences.print_header = gnome_config_get_int("/" PACKAGE "/Print Settings/print_header=1");
+   general_preferences.print_with_wrap = gnome_config_get_int("/" PACKAGE "/Print Settings/print_with_wrap=0");
+   general_preferences.print_numbers = gnome_config_get_int("/" PACKAGE "/Print Settings/print_numbers=1");
+   general_preferences.print_every_n_lines = gnome_config_get_int("/" PACKAGE "/Print Settings/print_every_n_lines=1");
+
+   // Style Settings
    text = gnome_config_get_string("/" PACKAGE "/Fonts/font_name");
    if(text && strlen(text) > 0)
    {
@@ -117,6 +157,13 @@ void get_prefs(void)
    general_preferences.gutter_bg.green = gnome_config_get_int("/" PACKAGE "/Colors/gutter_bg.green");
    general_preferences.gutter_bg.blue = gnome_config_get_int("/" PACKAGE "/Colors/gutter_bg.blue");
 
+   general_preferences.nb_normal.red = gnome_config_get_int("/" PACKAGE "/Colors/nb_normal.red=0");
+   general_preferences.nb_normal.green = gnome_config_get_int("/" PACKAGE "/Colors/nb_normal.green=0");
+   general_preferences.nb_normal.blue = gnome_config_get_int("/" PACKAGE "/Colors/nb_normal.blue=0");
+   general_preferences.nb_changed.red = gnome_config_get_int("/" PACKAGE "/Colors/nb_changed.red=65535");
+   general_preferences.nb_changed.green = gnome_config_get_int("/" PACKAGE "/Colors/nb_changed.green=0");
+   general_preferences.nb_changed.blue = gnome_config_get_int("/" PACKAGE "/Colors/nb_changed.blue=0");
+
    text = gnome_config_get_string("/" PACKAGE "/Background/background");
    if(text && strlen(text) > 0)
    {
@@ -124,41 +171,6 @@ void get_prefs(void)
       g_free(text);
    }
 
-   general_preferences.full_filenames_title = gnome_config_get_int("/" PACKAGE "/File Settings/full_filenames_title=0");
-   general_preferences.full_filenames = gnome_config_get_int("/" PACKAGE "/File Settings/full_filenames=0");
-   general_preferences.close_all = gnome_config_get_int("/" PACKAGE "/File Settings/close_all=1");
-   general_preferences.untitled = gnome_config_get_int("/" PACKAGE "/File Settings/untitled=1");
-   general_preferences.draw_numbers = gnome_config_get_int("/" PACKAGE "/File Settings/draw_numbers=0");
-   general_preferences.draw_pixmaps = gnome_config_get_int("/" PACKAGE "/File Settings/draw_pixmaps=0");
-   general_preferences.cursor_blink = gnome_config_get_int("/" PACKAGE "/File Settings/cursor_blink=1");
-   general_preferences.full_selection = gnome_config_get_int("/" PACKAGE "/File Settings/full_selection=1");
-   general_preferences.bracketmatch = gnome_config_get_int("/" PACKAGE "/File Settings/bracketmatch=1");
-   general_preferences.select_line = gnome_config_get_int("/" PACKAGE "/File Settings/select_line=0");
-   general_preferences.syntax = gnome_config_get_int("/" PACKAGE "/File Settings/syntax=1");
-   general_preferences.auto_indent = gnome_config_get_int("/" PACKAGE "/File Settings/auto_indent=1");
-   general_preferences.tab_stops = gnome_config_get_int("/" PACKAGE "/File Settings/tab_stops=1");
-   general_preferences.use_spaces = gnome_config_get_int("/" PACKAGE "/File Settings/use_spaces=0");
-   general_preferences.spaces = gnome_config_get_int("/" PACKAGE "/File Settings/spaces=4");
-
-   general_preferences.geometry = gnome_config_get_int("/" PACKAGE "/Geometry/use");
-   general_preferences.x = gnome_config_get_int("/" PACKAGE "/Geometry/x");
-   general_preferences.y = gnome_config_get_int("/" PACKAGE "/Geometry/y");
-   general_preferences.w = gnome_config_get_int("/" PACKAGE "/Geometry/w");
-   general_preferences.h = gnome_config_get_int("/" PACKAGE "/Geometry/h");
-
-   text = gnome_config_get_string("/" PACKAGE "/Print Settings/print_font");
-   if(text && strlen(text) > 0)
-   {
-      strcpy(general_preferences.print_font, text);
-      g_free(text);
-   }
-
-   general_preferences.print_landscape = gnome_config_get_int("/" PACKAGE "/Print Settings/print_landscape=0");
-   general_preferences.print_header = gnome_config_get_int("/" PACKAGE "/Print Settings/print_header=1");
-   general_preferences.print_with_wrap = gnome_config_get_int("/" PACKAGE "/Print Settings/print_with_wrap=0");
-   general_preferences.print_numbers = gnome_config_get_int("/" PACKAGE "/Print Settings/print_numbers=1");
-   general_preferences.print_every_n_lines = gnome_config_get_int("/" PACKAGE "/Print Settings/print_every_n_lines=1");
-
    case_sensitive = gnome_config_get_int("/" PACKAGE "/Find-Replace/case_sensitive=0");
    search_style = gnome_config_get_int("/" PACKAGE "/Find-Replace/search_style=0");
    search_start = gnome_config_get_int("/" PACKAGE "/Find-Replace/search_start=0");
@@ -169,6 +181,21 @@ void get_prefs(void)
 void save_prefs(void)
 {
    gchar *text;
+
+   gnome_config_set_int("/" PACKAGE "/File Settings/full_filenames_title", general_preferences.full_filenames_title);
+   gnome_config_set_int("/" PACKAGE "/File Settings/full_filenames", general_preferences.full_filenames);
+   gnome_config_set_int("/" PACKAGE "/File Settings/async_xfer", general_preferences.async_xfer);
+   gnome_config_set_int("/" PACKAGE "/File Settings/close_all", general_preferences.close_all);
+   gnome_config_set_int("/" PACKAGE "/File Settings/untitled", general_preferences.untitled);
+   gnome_config_set_int("/" PACKAGE "/File Settings/show_dots", general_preferences.show_dots);
+   gnome_config_set_int("/" PACKAGE "/File Settings/show_details", general_preferences.show_details);
+   gnome_config_set_int("/" PACKAGE "/File Settings/draw_numbers", general_preferences.draw_numbers);
+   gnome_config_set_int("/" PACKAGE "/File Settings/draw_pixmaps", general_preferences.draw_pixmaps);
+   gnome_config_set_int("/" PACKAGE "/File Settings/cursor_blink", general_preferences.cursor_blink);
+   gnome_config_set_int("/" PACKAGE "/File Settings/full_selection", general_preferences.full_selection);
+   gnome_config_set_int("/" PACKAGE "/General/toolbar_style", general_preferences.toolbar_style);
+   gnome_config_set_int("/" PACKAGE "/General/tab_position", general_preferences.notebook_tab_position);
+
    text = general_preferences.default_dir;
    gnome_config_set_string("/" PACKAGE "/General/default_dir", text);
    text = general_preferences.projects_dir;
@@ -176,9 +203,9 @@ void save_prefs(void)
    gnome_config_set_int("/" PACKAGE "/General/save_toolbars", general_preferences.save_toolbars);
    gnome_config_set_int("/" PACKAGE "/General/save_session", general_preferences.save_session);
    gnome_config_set_int("/" PACKAGE "/General/open_session", general_preferences.open_session);
+   gnome_config_set_int("/" PACKAGE "/General/auto_save", general_preferences.auto_save);
    gnome_config_set_int("/" PACKAGE "/General/history_items", general_preferences.history);
    gnome_config_set_int("/" PACKAGE "/General/undo_max", general_preferences.undo_max);
-   gnome_config_set_int("/" PACKAGE "/General/tab_position", general_preferences.notebook_tab_position);
 
    text = general_preferences.terminal;
    gnome_config_set_string("/" PACKAGE "/Build/terminal", text);
@@ -190,6 +217,28 @@ void save_prefs(void)
    text = general_preferences.email;
    gnome_config_set_string("/" PACKAGE "/User Settings/email", text);
 
+   gnome_config_set_int("/" PACKAGE "/File Settings/bracketmatch", general_preferences.bracketmatch);
+   gnome_config_set_int("/" PACKAGE "/File Settings/select_line", general_preferences.select_line);
+   gnome_config_set_int("/" PACKAGE "/File Settings/syntax", general_preferences.syntax);
+   gnome_config_set_int("/" PACKAGE "/File Settings/auto_indent", general_preferences.auto_indent);
+   gnome_config_set_int("/" PACKAGE "/File Settings/tab_stops", general_preferences.tab_stops);
+   gnome_config_set_int("/" PACKAGE "/File Settings/use_spaces", general_preferences.use_spaces);
+   gnome_config_set_int("/" PACKAGE "/File Settings/spaces", general_preferences.spaces);
+
+   gnome_config_set_int("/" PACKAGE "/Geometry/use", general_preferences.geometry);
+   gnome_config_set_int("/" PACKAGE "/Geometry/x", general_preferences.x);
+   gnome_config_set_int("/" PACKAGE "/Geometry/y", general_preferences.y);
+   gnome_config_set_int("/" PACKAGE "/Geometry/w", general_preferences.w);
+   gnome_config_set_int("/" PACKAGE "/Geometry/h", general_preferences.h);
+
+   text = general_preferences.print_font;
+   gnome_config_set_string("/" PACKAGE "/Print Settings/print_font", text);
+   gnome_config_set_int("/" PACKAGE "/Print Settings/print_landscape", general_preferences.print_landscape);
+   gnome_config_set_int("/" PACKAGE "/Print Settings/print_header", general_preferences.print_header);
+   gnome_config_set_int("/" PACKAGE "/Print Settings/print_with_wrap", general_preferences.print_with_wrap);
+   gnome_config_set_int("/" PACKAGE "/Print Settings/print_numbers", general_preferences.print_numbers);
+   gnome_config_set_int("/" PACKAGE "/Print Settings/print_every_n_lines", general_preferences.print_every_n_lines);
+
    text = general_preferences.font_name;
    gnome_config_set_string("/" PACKAGE "/Fonts/font_name", text);
    text = general_preferences.italic_name;
@@ -216,44 +265,37 @@ void save_prefs(void)
    gnome_config_set_int("/" PACKAGE "/Colors/gutter_bg.green", general_preferences.gutter_bg.green);
    gnome_config_set_int("/" PACKAGE "/Colors/gutter_bg.blue", general_preferences.gutter_bg.blue);
 
+   gnome_config_set_int("/" PACKAGE "/Colors/nb_normal.red", general_preferences.nb_normal.red);
+   gnome_config_set_int("/" PACKAGE "/Colors/nb_normal.green", general_preferences.nb_normal.green);
+   gnome_config_set_int("/" PACKAGE "/Colors/nb_normal.blue", general_preferences.nb_normal.blue);
+   gnome_config_set_int("/" PACKAGE "/Colors/nb_changed.red", general_preferences.nb_changed.red);
+   gnome_config_set_int("/" PACKAGE "/Colors/nb_changed.green", general_preferences.nb_changed.green);
+   gnome_config_set_int("/" PACKAGE "/Colors/nb_changed.blue", general_preferences.nb_changed.blue);
+
    text = general_preferences.pixmap_name;
    gnome_config_set_string("/" PACKAGE "/Background/background", text);
 
-   gnome_config_set_int("/" PACKAGE "/File Settings/full_filenames_title", general_preferences.full_filenames_title);
-   gnome_config_set_int("/" PACKAGE "/File Settings/full_filenames", general_preferences.full_filenames);
-   gnome_config_set_int("/" PACKAGE "/File Settings/close_all", general_preferences.close_all);
-   gnome_config_set_int("/" PACKAGE "/File Settings/untitled", general_preferences.untitled);
-   gnome_config_set_int("/" PACKAGE "/File Settings/draw_numbers", general_preferences.draw_numbers);
-   gnome_config_set_int("/" PACKAGE "/File Settings/draw_pixmaps", general_preferences.draw_pixmaps);
-   gnome_config_set_int("/" PACKAGE "/File Settings/cursor_blink", general_preferences.cursor_blink);
-   gnome_config_set_int("/" PACKAGE "/File Settings/full_selection", general_preferences.full_selection);
-   gnome_config_set_int("/" PACKAGE "/File Settings/bracketmatch", general_preferences.bracketmatch);
-   gnome_config_set_int("/" PACKAGE "/File Settings/select_line", general_preferences.select_line);
-   gnome_config_set_int("/" PACKAGE "/File Settings/syntax", general_preferences.syntax);
-   gnome_config_set_int("/" PACKAGE "/File Settings/auto_indent", general_preferences.auto_indent);
-   gnome_config_set_int("/" PACKAGE "/File Settings/tab_stops", general_preferences.tab_stops);
-   gnome_config_set_int("/" PACKAGE "/File Settings/use_spaces", general_preferences.use_spaces);
-   gnome_config_set_int("/" PACKAGE "/File Settings/spaces", general_preferences.spaces);
-
-   gnome_config_set_int("/" PACKAGE "/Geometry/use", general_preferences.geometry);
-   gnome_config_set_int("/" PACKAGE "/Geometry/x", general_preferences.x);
-   gnome_config_set_int("/" PACKAGE "/Geometry/y", general_preferences.y);
-   gnome_config_set_int("/" PACKAGE "/Geometry/w", general_preferences.w);
-   gnome_config_set_int("/" PACKAGE "/Geometry/h", general_preferences.h);
-
-   text = general_preferences.print_font;
-   gnome_config_set_string("/" PACKAGE "/Print Settings/print_font", text);
-   gnome_config_set_int("/" PACKAGE "/Print Settings/print_landscape", general_preferences.print_landscape);
-   gnome_config_set_int("/" PACKAGE "/Print Settings/print_header", general_preferences.print_header);
-   gnome_config_set_int("/" PACKAGE "/Print Settings/print_with_wrap", general_preferences.print_with_wrap);
-   gnome_config_set_int("/" PACKAGE "/Print Settings/print_numbers", general_preferences.print_numbers);
-   gnome_config_set_int("/" PACKAGE "/Print Settings/print_every_n_lines", general_preferences.print_every_n_lines);
    gnome_config_sync();
 }
 
 void save_defaults(void)
 {
    gchar *text;
+
+   gnome_config_set_int("/" PACKAGE "/File Settings/full_filenames_title", default_preferences.full_filenames_title);
+   gnome_config_set_int("/" PACKAGE "/File Settings/full_filenames", default_preferences.full_filenames);
+   gnome_config_set_int("/" PACKAGE "/File Settings/async_xfer", default_preferences.async_xfer);
+   gnome_config_set_int("/" PACKAGE "/File Settings/close_all", default_preferences.close_all);
+   gnome_config_set_int("/" PACKAGE "/File Settings/untitled", default_preferences.untitled);
+   gnome_config_set_int("/" PACKAGE "/File Settings/show_dots", default_preferences.show_dots);
+   gnome_config_set_int("/" PACKAGE "/File Settings/show_details", default_preferences.show_details);
+   gnome_config_set_int("/" PACKAGE "/File Settings/draw_numbers", default_preferences.draw_numbers);
+   gnome_config_set_int("/" PACKAGE "/File Settings/draw_pixmaps", default_preferences.draw_pixmaps);
+   gnome_config_set_int("/" PACKAGE "/File Settings/cursor_blink", default_preferences.cursor_blink);
+   gnome_config_set_int("/" PACKAGE "/File Settings/full_selection", default_preferences.full_selection);
+   gnome_config_set_int("/" PACKAGE "/General/toolbar_style", default_preferences.toolbar_style);
+   gnome_config_set_int("/" PACKAGE "/General/tab_position", default_preferences.notebook_tab_position);
+
    text = default_preferences.default_dir;
    gnome_config_set_string("/" PACKAGE "/General/default_dir", text);
    text = default_preferences.projects_dir;
@@ -261,9 +303,9 @@ void save_defaults(void)
    gnome_config_set_int("/" PACKAGE "/General/save_toolbars", default_preferences.save_toolbars);
    gnome_config_set_int("/" PACKAGE "/General/save_session", default_preferences.save_session);
    gnome_config_set_int("/" PACKAGE "/General/open_session", default_preferences.open_session);
+   gnome_config_set_int("/" PACKAGE "/General/auto_save", default_preferences.auto_save);
    gnome_config_set_int("/" PACKAGE "/General/history_items", default_preferences.history);
    gnome_config_set_int("/" PACKAGE "/General/undo_max", default_preferences.undo_max);
-   gnome_config_set_int("/" PACKAGE "/General/tab_position", default_preferences.notebook_tab_position);   
 
    text = default_preferences.terminal;
    gnome_config_set_string("/" PACKAGE "/Build/terminal", text);
@@ -275,6 +317,28 @@ void save_defaults(void)
    text = default_preferences.email;
    gnome_config_set_string("/" PACKAGE "/User Settings/email", text);
 
+   gnome_config_set_int("/" PACKAGE "/File Settings/bracketmatch", default_preferences.bracketmatch);
+   gnome_config_set_int("/" PACKAGE "/File Settings/select_line", default_preferences.select_line);
+   gnome_config_set_int("/" PACKAGE "/File Settings/syntax", default_preferences.syntax);
+   gnome_config_set_int("/" PACKAGE "/File Settings/auto_indent", default_preferences.auto_indent);
+   gnome_config_set_int("/" PACKAGE "/File Settings/tab_stops", default_preferences.tab_stops);
+   gnome_config_set_int("/" PACKAGE "/File Settings/use_spaces", default_preferences.use_spaces);
+   gnome_config_set_int("/" PACKAGE "/File Settings/spaces", default_preferences.spaces);
+
+   gnome_config_set_int("/" PACKAGE "/Geometry/use", default_preferences.geometry);
+   gnome_config_set_int("/" PACKAGE "/Geometry/x", default_preferences.x);
+   gnome_config_set_int("/" PACKAGE "/Geometry/y", default_preferences.y);
+   gnome_config_set_int("/" PACKAGE "/Geometry/w", default_preferences.w);
+   gnome_config_set_int("/" PACKAGE "/Geometry/h", default_preferences.h);
+
+   text = default_preferences.print_font;
+   gnome_config_set_string("/" PACKAGE "/Print Settings/print_font", text);
+   gnome_config_set_int("/" PACKAGE "/Print Settings/print_landscape", default_preferences.print_landscape);
+   gnome_config_set_int("/" PACKAGE "/Print Settings/print_header", default_preferences.print_header);
+   gnome_config_set_int("/" PACKAGE "/Print Settings/print_with_wrap", default_preferences.print_with_wrap);
+   gnome_config_set_int("/" PACKAGE "/Print Settings/print_numbers", default_preferences.print_numbers);
+   gnome_config_set_int("/" PACKAGE "/Print Settings/print_every_n_lines", default_preferences.print_every_n_lines);
+
    text = default_preferences.font_name;
    gnome_config_set_string("/" PACKAGE "/Fonts/font_name", text);
    text = default_preferences.italic_name;
@@ -301,38 +365,16 @@ void save_defaults(void)
    gnome_config_set_int("/" PACKAGE "/Colors/gutter_bg.green", default_preferences.gutter_bg.green);
    gnome_config_set_int("/" PACKAGE "/Colors/gutter_bg.blue", default_preferences.gutter_bg.blue);
 
+   gnome_config_set_int("/" PACKAGE "/Colors/nb_normal.red", default_preferences.nb_normal.red);
+   gnome_config_set_int("/" PACKAGE "/Colors/nb_normal.green", default_preferences.nb_normal.green);
+   gnome_config_set_int("/" PACKAGE "/Colors/nb_normal.blue", default_preferences.nb_normal.blue);
+   gnome_config_set_int("/" PACKAGE "/Colors/nb_changed.red", default_preferences.nb_changed.red);
+   gnome_config_set_int("/" PACKAGE "/Colors/nb_changed.green", default_preferences.nb_changed.green);
+   gnome_config_set_int("/" PACKAGE "/Colors/nb_changed.blue", default_preferences.nb_changed.blue);
+
    text = default_preferences.pixmap_name;
    gnome_config_set_string("/" PACKAGE "/Background/background", text);
 
-   gnome_config_set_int("/" PACKAGE "/File Settings/full_filenames_title", default_preferences.full_filenames_title);
-   gnome_config_set_int("/" PACKAGE "/File Settings/full_filenames", default_preferences.full_filenames);
-   gnome_config_set_int("/" PACKAGE "/File Settings/close_all", default_preferences.close_all);
-   gnome_config_set_int("/" PACKAGE "/File Settings/untitled", default_preferences.untitled);
-   gnome_config_set_int("/" PACKAGE "/File Settings/draw_numbers", default_preferences.draw_numbers);
-   gnome_config_set_int("/" PACKAGE "/File Settings/draw_pixmaps", default_preferences.draw_pixmaps);
-   gnome_config_set_int("/" PACKAGE "/File Settings/cursor_blink", default_preferences.cursor_blink);
-   gnome_config_set_int("/" PACKAGE "/File Settings/full_selection", default_preferences.full_selection);
-   gnome_config_set_int("/" PACKAGE "/File Settings/bracketmatch", default_preferences.bracketmatch);
-   gnome_config_set_int("/" PACKAGE "/File Settings/select_line", default_preferences.select_line);
-   gnome_config_set_int("/" PACKAGE "/File Settings/syntax", default_preferences.syntax);
-   gnome_config_set_int("/" PACKAGE "/File Settings/auto_indent", default_preferences.auto_indent);
-   gnome_config_set_int("/" PACKAGE "/File Settings/tab_stops", default_preferences.tab_stops);
-   gnome_config_set_int("/" PACKAGE "/File Settings/use_spaces", default_preferences.use_spaces);
-   gnome_config_set_int("/" PACKAGE "/File Settings/spaces", default_preferences.spaces);
-
-   gnome_config_set_int("/" PACKAGE "/Geometry/use", default_preferences.geometry);
-   gnome_config_set_int("/" PACKAGE "/Geometry/x", default_preferences.x);
-   gnome_config_set_int("/" PACKAGE "/Geometry/y", default_preferences.y);
-   gnome_config_set_int("/" PACKAGE "/Geometry/w", default_preferences.w);
-   gnome_config_set_int("/" PACKAGE "/Geometry/h", default_preferences.h);
-
-   text = default_preferences.print_font;
-   gnome_config_set_string("/" PACKAGE "/Print Settings/print_font", text);
-   gnome_config_set_int("/" PACKAGE "/Print Settings/print_landscape", default_preferences.print_landscape);
-   gnome_config_set_int("/" PACKAGE "/Print Settings/print_header", default_preferences.print_header);
-   gnome_config_set_int("/" PACKAGE "/Print Settings/print_with_wrap", default_preferences.print_with_wrap);
-   gnome_config_set_int("/" PACKAGE "/Print Settings/print_numbers", default_preferences.print_numbers);
-   gnome_config_set_int("/" PACKAGE "/Print Settings/print_every_n_lines", default_preferences.print_every_n_lines);
    gnome_config_sync();
 }
 
@@ -350,8 +392,22 @@ void build_defaults(void)
    gchar *home = NULL;
    gchar *user = NULL;
    gchar *hostname = NULL;
-   home = getenv("HOME");
-   user = getenv("USER");
+
+   default_preferences.full_filenames_title = FALSE;
+   default_preferences.full_filenames = FALSE;
+   default_preferences.async_xfer = FALSE;
+   default_preferences.close_all = FALSE;
+   default_preferences.untitled = TRUE;
+   default_preferences.show_dots = TRUE;
+   default_preferences.show_details = FALSE;
+   default_preferences.draw_numbers = FALSE;
+   default_preferences.draw_pixmaps = FALSE;
+   default_preferences.cursor_blink = TRUE;
+   default_preferences.full_selection = FALSE;
+   default_preferences.toolbar_style = GTK_TOOLBAR_ICONS;
+   default_preferences.notebook_tab_position = GTK_POS_TOP;
+   home = g_get_home_dir();
+   user = g_get_user_name();
    hostname = getenv("HOSTNAME");
    strncpy(default_preferences.default_dir, home, sizeof(default_preferences.default_dir));
    g_snprintf(default_preferences.projects_dir, sizeof(default_preferences.projects_dir), "%s/Projects", home);
@@ -364,9 +420,32 @@ void build_defaults(void)
    default_preferences.save_toolbars = TRUE;
    default_preferences.save_session = TRUE;
    default_preferences.open_session = TRUE;
+   default_preferences.auto_save = TRUE;
    default_preferences.history = 15;
-   default_preferences.undo_max = 20;
-   default_preferences.notebook_tab_position = GTK_POS_TOP;
+   default_preferences.undo_max = 30;
+
+   default_preferences.bracketmatch = TRUE;
+   default_preferences.select_line = FALSE;
+   default_preferences.syntax = TRUE;
+   default_preferences.auto_indent = TRUE;
+   default_preferences.tab_stops = FALSE;
+   default_preferences.use_spaces = FALSE;
+   default_preferences.spaces = 4;
+
+   default_preferences.geometry = 0;
+   default_preferences.x = 0;
+   default_preferences.y = 0;
+   default_preferences.w = 750;
+   default_preferences.h = 450;
+
+   strcpy(default_preferences.print_font, "Courier 12.000000");
+   strcpy(general_preferences.print_font, default_preferences.print_font);
+   default_preferences.print_landscape = 0;
+   default_preferences.print_header = 1;
+   default_preferences.print_with_wrap = 0;
+   default_preferences.print_numbers = 1;
+   default_preferences.print_every_n_lines = 1;
+
    default_preferences.use_gtk_theme = FALSE;
    default_preferences.font = general_preferences.font = NULL;
    strcpy(default_preferences.font_name, "-adobe-courier-medium-r-normal-*-17-*-*-*-m-*-iso8859-1");
@@ -392,37 +471,17 @@ void build_defaults(void)
    default_preferences.gutter_bg = general_preferences.gutter_bg = style->bg[GTK_STATE_INSENSITIVE];
    DefaultCache.colors[DEFAULT] = HighlightCache.colors[DEFAULT] = default_preferences.fg;
    gtk_widget_destroy(win);
+
+   default_preferences.nb_normal.red = 0;
+   default_preferences.nb_normal.green = 0;
+   default_preferences.nb_normal.blue = 0;
+   default_preferences.nb_changed.red = 0;
+   default_preferences.nb_changed.green = 0;
+   default_preferences.nb_changed.blue = 0;
+
    default_preferences.bg_pixmap = general_preferences.bg_pixmap = NULL;
    strcpy(default_preferences.pixmap_name, "");
    strcpy(general_preferences.pixmap_name, default_preferences.pixmap_name);
-
-   default_preferences.full_filenames_title = FALSE;
-   default_preferences.full_filenames = FALSE;
-   default_preferences.close_all = FALSE;
-   default_preferences.untitled = TRUE;
-   default_preferences.draw_numbers = FALSE;
-   default_preferences.draw_pixmaps = FALSE;
-   default_preferences.cursor_blink = TRUE;
-   default_preferences.full_selection = FALSE;
-   default_preferences.bracketmatch = TRUE;
-   default_preferences.select_line = FALSE;
-   default_preferences.syntax = TRUE;
-   default_preferences.auto_indent = TRUE;
-   default_preferences.tab_stops = FALSE;
-   default_preferences.use_spaces = FALSE;
-   default_preferences.spaces = 4;
-   default_preferences.geometry = 0;
-   default_preferences.x = 0;
-   default_preferences.y = 0;
-   default_preferences.w = 750;
-   default_preferences.h = 450;
-   strcpy(default_preferences.print_font, "Courier 12.000000");
-   strcpy(general_preferences.print_font, default_preferences.print_font);
-   default_preferences.print_landscape = 0;
-   default_preferences.print_header = 1;
-   default_preferences.print_with_wrap = 0;
-   default_preferences.print_numbers = 1;
-   default_preferences.print_every_n_lines = 1;
 }
 
 void get_saved_colors(void)
@@ -453,7 +512,7 @@ void get_saved_colors(void)
          HighlightCache.types[i] = info->type;
          HighlightCache.flags[i] = info->flags;
          g_free(info);
-         g_free(text); /* Memprof claims there is a leak here. This line should fix it. */
+         g_free(text);
       }
    }
 }
