@@ -1,21 +1,21 @@
 /*  GtkExText
- * This is my first GtkWidget
- * GtkExText is Copyright (C) 1999 by:
- * Mikael Hermansson <mikeh@bahnhof.se>
+ *  Copyright (C) 1999, 2000 
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ *  Mikael Hermansson <mikeh@bahnhof.se>
+ *  Chris Phelps <chicane@reninet.com>
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Library General Public License for more details.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  You should have received a copy of the GNU Library General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 #ifndef GTK_EXTEXT_H__
@@ -26,10 +26,15 @@ extern "C"
 #endif
 
 #include <gdk/gdk.h>
-#include <gtk/gtkadjustment.h>
+#include <gtk/gtk.h>
 
 #include <sys/types.h>
-#include "../regex/regex.h"
+
+#ifdef WITH_SYSTEM_REGEX
+#include <regex.h>
+#else
+#include "regex.h"
+#endif
 
 #define GTK_TYPE_EXTEXT                  (gtk_extext_get_type ())
 #define GTK_EXTEXT(obj)                  (GTK_CHECK_CAST ((obj), GTK_TYPE_EXTEXT, GtkExText))
@@ -91,6 +96,66 @@ extern "C"
   }
   GtkExTextStyle;
 
+  typedef struct _Regex
+  {
+    struct re_pattern_buffer buf;
+    struct re_registers reg;
+  }
+  Regex;
+
+  typedef enum
+  {
+     SYNTAX_TABLE,
+     PATTERN_TABLE,
+     EMBEDDED_TABLE
+  }GtkExTextHighlightTableType;
+  
+  typedef struct _GtkExTextSyntaxEntry
+  {
+     gchar *start;
+     Regex regex_start;
+     Regex regex_end;
+     gchar key[32];
+     GdkFont *font;
+     GdkColor *color;
+     GdkColor *bg;
+     guint16 flags;
+     gpointer data;
+     gint ref_count;
+  }GtkExTextSyntaxEntry;
+  
+  typedef struct _GtkExTextPatternEntry
+  {
+     Regex regex;
+     gchar key[32];
+     GdkFont *font;
+     GdkColor *color;
+     GdkColor *bg;
+     guint16 flags;
+     gpointer data;
+     gint ref_count;
+  }GtkExTextPatternEntry;
+  
+  typedef struct _GtkExTextEmbeddedEntry
+  {
+     Regex outside;
+     Regex inside;
+     gchar key[32];
+     GdkFont *font;
+     GdkColor *color;
+     GdkColor *bg;
+     guint16 flags;
+     gpointer data;
+     gint ref_count;
+  }GtkExTextEmbeddedEntry;
+  
+  typedef struct _GtkExTextHighlightTable
+  {
+     GtkExTextHighlightTableType type;
+     GList *entries; 
+     Regex regex_all;
+  }GtkExTextHighlightTable;
+
 /* Line struct */
 /* holds all lines */
 /* all lines ends with "\n" character */
@@ -227,7 +292,6 @@ extern "C"
     guint cursor_blink:1;
 
     /* Undo coding */
-    /* FIXED/Replaced by Chicane */
     gint undo_max;
     GList *undo_redo;
     guint undo_level;
@@ -244,9 +308,12 @@ extern "C"
     /* number_width + pixmap_width */
     gint gutter_width;
 
+    guint highlight:1;
     guint select_line:1;
     guint draw_cursor:1;
     guint full_selection:1;
+    guint show_whitespace:1;
+    guint show_newlines:1;
     guint pseudo_select:1;
     gint pseudo_start;
     gint pseudo_end;
@@ -266,6 +333,11 @@ extern "C"
 
     /* hash list with font/color styles */
     GHashTable *hash_styles;
+
+    /* List of all the stuff we want to highlight */
+    GtkExTextHighlightTable *syntax_table;
+    GtkExTextHighlightTable *pattern_table;
+    GtkExTextHighlightTable *embedded_table;
   };
 
   struct _GtkExTextClass
@@ -452,6 +524,8 @@ extern "C"
   void gtk_extext_set_cursor_blink (GtkExText * text, gboolean blink);
   void gtk_extext_set_draw_cursor (GtkExText * text, gboolean draw);
   void gtk_extext_set_full_selection (GtkExText * text, gboolean full);
+  void gtk_extext_set_show_newlines (GtkExText * text, gboolean show);
+  void gtk_extext_set_show_whitespace (GtkExText * text, gboolean show);
 
   gint gtk_extext_get_tab_width (GtkExText * text);
   void gtk_extext_set_tab_width (GtkExText * text, gint width);
@@ -471,6 +545,23 @@ extern "C"
 
   GtkType gtk_extext_get_type (void);
 
+  gboolean gtk_extext_compile_regex (const gchar *pattern, Regex *regex);
+
+  void gtk_extext_set_highlight(GtkExText *text, gboolean value);
+  void gtk_extext_highlight(GtkExText *text);
+
+  GtkExTextHighlightTable *gtk_extext_syntax_table_new(GList *entries);
+  GtkExTextHighlightTable *gtk_extext_pattern_table_new(GList *entries);
+  GtkExTextHighlightTable *gtk_extext_embedded_table_new(GList *entries);
+  
+  void gtk_extext_table_free(GtkExTextHighlightTable *table);
+  
+  GList *gtk_extext_syntax_entry_new(GList *entries, gchar *name, gchar *start, gchar *end, GdkColor *fg, GdkColor *bg, GdkFont *font, guint16 flags, gpointer data);
+  GList *gtk_extext_pattern_entry_new(GList *entries, gchar *name, gchar *start, GdkColor *fg, GdkColor *bg, GdkFont *font, guint16 flags, gpointer data);
+  GList *gtk_extext_embedded_entry_new(GList *entries, gchar *name, gchar *outside, gchar *inside, GdkColor *fg, GdkColor *bg, GdkFont *font, guint16 flags, gpointer data);
+  
+  void gtk_extext_install_table(GtkExText *text, GtkExTextHighlightTable *table);
+
 #define GTK_EXTEXT_INDEX(extext,index) (index < extext->part1len ? \
                                       extext->text[index] : extext->part2text[index])
 
@@ -480,13 +571,6 @@ extern "C"
 			      GtkExTextMatch * m);
 
 /* Regex functions */
-  typedef struct _Regex
-  {
-    struct re_pattern_buffer buf;
-    struct re_registers reg;
-  }
-  Regex;
-
   gint gtk_extext_regex_search (GtkExText * text, gint start, Regex * regex,
 				gboolean forward, GtkExTextMatch * m);
   gint gtk_extext_regex_match (GtkExText * text, gint pos, Regex * regex);
