@@ -7,13 +7,16 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include <libgnomevfs/gnome-vfs-types.h>
+#include <libgnomevfs/gnome-vfs-uri.h>
+
 #include "declarations.h"
 #include "insert.h"
 #include "dialogs.h"
@@ -23,7 +26,7 @@
 #include "settings.h"
 
 static void insert_ascii_char(GtkWidget *widget, GnomeAsciiList *ascii);
-static void insert_file_cb_continue(GtkWidget *widget, GnomeFileList *file_list);
+static void insert_file_cb_continue(GtkWidget *widget, GnomeFileSelector *file_list);
 static void insert_file_real(gchar *filename);
 static void insert_color_cb_continue(GtkWidget *widget, GtkColorSelectionDialog *colorsel);
 static void runcmd_cb_continue(GtkWidget *widget, GnomeRunCmd *grc);
@@ -84,7 +87,7 @@ void insert_gpl_notice(GtkWidget *widget, gpointer data)
       " *  This program is distributed in the hope that it will be useful,\n"
       " *  but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
       " *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
-      " *  GNU Library General Public License for more details.\n"
+      " *  GNU General Public License for more details.\n"
       " *\n"
       " *  You should have received a copy of the GNU General Public License\n"
       " *  along with this program; if not, write to the Free Software\n"
@@ -110,7 +113,7 @@ void insert_gpl_noticepp(GtkWidget *widget, gpointer data)
       "// This program is distributed in the hope that it will be useful,\n"
       "// but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
       "// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
-      "// GNU Library General Public License for more details.\n"
+      "// GNU General Public License for more details.\n"
       "//\n"
       "// You should have received a copy of the GNU General Public License\n"
       "// along with this program; if not, write to the Free Software\n"
@@ -137,7 +140,7 @@ void insert_gpl_noticepython(GtkWidget *widget, gpointer data)
       "# This program is distributed in the hope that it will be useful,\n"
       "# but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
       "# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
-      "# GNU Library General Public License for more details.\n"
+      "# GNU General Public License for more details.\n"
       "#\n"
       "# You should have received a copy of the GNU General Public License\n"
       "# along with this program; if not, write to the Free Software\n"
@@ -149,6 +152,87 @@ void insert_gpl_noticepython(GtkWidget *widget, gpointer data)
    gds_editor_insert_text(GDS_EDITOR(extext), gpl_notice, strlen(gpl_notice), (gint *)&extext->current_pos);
 }
 
+void insert_lgpl_notice(GtkWidget *widget, gpointer data)
+{
+   GtkExText *extext;
+
+   gchar *lgpl_notice =
+   {
+      "/*\n"
+      " *  This library is free software; you can redistribute it and/or modify\n"
+      " *  it under the terms of the GNU Library General Public License as published by\n"
+      " *  the Free Software Foundation; either version 2 of the License, or\n"
+      " *  (at your option) any later version.\n"
+      " *\n"
+      " *  This library is distributed in the hope that it will be useful,\n"
+      " *  but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
+      " *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
+      " *  GNU Library General Public License for more details.\n"
+      " *\n"
+      " *  You should have received a copy of the GNU Library General Public License\n"
+      " *  along with this program; if not, write to the Free Software\n"
+      " *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.\n"
+      " */\n"
+   };
+
+   extext = GTK_EXTEXT(cur_file->text);
+   gds_editor_insert_text(GDS_EDITOR(extext), lgpl_notice, strlen(lgpl_notice), (gint *)&extext->current_pos);
+}
+
+void insert_lgpl_noticepp(GtkWidget *widget, gpointer data)
+{
+   GtkExText *extext;
+
+   gchar lgpl_notice[] =
+   {
+      "// This library is free software; you can redistribute it and/or modify\n"
+      "// it under the terms of the GNU Library General Public License as published by\n"
+      "// the Free Software Foundation; either version 2 of the License, or\n"
+      "// (at your option) any later version.\n"
+      "//\n"
+      "// This library is distributed in the hope that it will be useful,\n"
+      "// but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
+      "// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
+      "// GNU Library General Public License for more details.\n"
+      "//\n"
+      "// You should have received a copy of the GNU Library General Public License\n"
+      "// along with this program; if not, write to the Free Software\n"
+      "// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.\n"
+      "\n"
+   };
+
+   extext = GTK_EXTEXT(cur_file->text);
+   gds_editor_insert_text(GDS_EDITOR(extext), lgpl_notice, strlen(lgpl_notice), (gint *)&extext->current_pos);
+}
+
+void insert_lgpl_noticepython(GtkWidget *widget, gpointer data)
+{
+   GtkExText *extext;
+
+   gchar *lgpl_notice =
+   {
+      "#\n"
+      "# This library is free software; you can redistribute it and/or modify\n"
+      "# it under the terms of the GNU Library General Public License as published by\n"
+      "# the Free Software Foundation; either version 2 of the License, or\n"
+      "# (at your option) any later version.\n"
+      "#\n"
+      "# This library is distributed in the hope that it will be useful,\n"
+      "# but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
+      "# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
+      "# GNU Library General Public License for more details.\n"
+      "#\n"
+      "# You should have received a copy of the GNU Library General Public License\n"
+      "# along with this program; if not, write to the Free Software\n"
+      "# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.\n"
+      "\n"
+   };
+
+   extext = GTK_EXTEXT(cur_file->text);
+   gds_editor_insert_text(GDS_EDITOR(extext), lgpl_notice, strlen(lgpl_notice), (gint *)&extext->current_pos);
+}
+
+
 void insert_changelog_string(GtkWidget *widget, gpointer data)
 {
    GtkExText *extext;
@@ -201,18 +285,27 @@ static void insert_ascii_char(GtkWidget *widget, GnomeAsciiList *ascii)
 
 void insert_file_cb(GtkWidget *widget, gpointer data)
 {
-   file_selector = last_dir ? gnome_filelist_new_with_path(last_dir) : gnome_filelist_new_with_path(general_preferences.default_dir);
-   gnome_filelist_set_title(GNOME_FILELIST(file_selector), _("Insert File..."));
-   gtk_signal_connect(GTK_OBJECT(GNOME_FILELIST(file_selector)->ok_button), "clicked", GTK_SIGNAL_FUNC(insert_file_cb_continue), file_selector);
-   gtk_signal_connect_object(GTK_OBJECT(GNOME_FILELIST(file_selector)->ok_button), "clicked", GTK_SIGNAL_FUNC(gtk_widget_destroy), GTK_OBJECT(file_selector));
-   gtk_signal_connect_object(GTK_OBJECT(GNOME_FILELIST(file_selector)->cancel_button), "clicked", GTK_SIGNAL_FUNC(gtk_widget_destroy), GTK_OBJECT(file_selector));
-   gtk_widget_show(file_selector);
+   static GtkWidget *file_selector = NULL;
+   if(!file_selector)
+   {
+      file_selector = gnome_file_selector_new_with_path(last_dir ? last_dir : general_preferences.default_dir, GNOME_FILE_SELECTOR_SINGLE, general_preferences.show_dots, general_preferences.show_details);
+      gnome_file_selector_set_title(GNOME_FILE_SELECTOR(file_selector), _("Insert File..."));
+      gtk_signal_connect(GTK_OBJECT(GNOME_FILE_SELECTOR(file_selector)->ok_button), "clicked", GTK_SIGNAL_FUNC(insert_file_cb_continue), file_selector);
+      gtk_signal_connect_object(GTK_OBJECT(GNOME_FILE_SELECTOR(widget)->cancel_button), "clicked", GTK_SIGNAL_FUNC(gtk_widget_hide), GTK_OBJECT(file_selector));
+      gtk_widget_show(file_selector);
+   }
+   else
+   {
+      gtk_entry_set_text(GTK_ENTRY(GNOME_FILE_SELECTOR(file_selector)->selection_entry), "");
+      gtk_widget_show(file_selector);
+   }
 }
 
-static void insert_file_cb_continue(GtkWidget *widget, GnomeFileList *file_list)
+static void insert_file_cb_continue(GtkWidget *widget, GnomeFileSelector *file_list)
 {
    gchar *string;
-   string = gnome_filelist_get_filename(GNOME_FILELIST(file_list));
+   string = gnome_file_selector_get_filename(GNOME_FILE_SELECTOR(file_list));
+   gtk_widget_hide(GTK_WIDGET(file_list));
    if(check_if_file_exists(string))
    {
       insert_file_real(string);
@@ -220,25 +313,20 @@ static void insert_file_cb_continue(GtkWidget *widget, GnomeFileList *file_list)
    else
    {
       read_error(string);
+      gtk_widget_show(GTK_WIDGET(file_list));
    }
    g_free(string);
 }
 
 static void insert_file_real(gchar *filename)
 {
-   gchar *temp = NULL;
+   GnomeVFSURI *uri;
    if(!cur_file) return;
-   temp = get_path_from_filename(filename);
-   if(temp && strcmp(filename, temp) != 0)
-   {
-      g_free(last_dir);
-      last_dir = g_new(char, strlen(temp)+1);
-      strcpy(last_dir, temp);
-   }
-   g_free(temp);
-   open_file_add_text(cur_file->text, filename);
+   uri = gnome_vfs_uri_new(filename);
+   open_file_full(cur_file, uri);
+   gnome_vfs_uri_unref(uri);
    adjust_sensitivity();
-   display_message("File Inserted.", FLASH);
+   display_message(_("File Inserted."), FLASH);
 }
 
 void insert_color_cb(GtkWidget *widget, gpointer data)
@@ -281,13 +369,13 @@ static void insert_color_cb_continue(GtkWidget *widget, GtkColorSelectionDialog
    b = colors[2] * 256;
    g_snprintf(string, sizeof(string), "#%02X%02X%02X", r, g, b);
    gtk_extext_insert_text(GTK_EXTEXT(cur_file->text), string, strlen(string), &GTK_EXTEXT(cur_file->text)->current_pos);
-   display_message("Color Inserted.", FLASH);
+   display_message(_("Color Inserted."), FLASH);
 }
 
 void runcmd_cb(GtkWidget *widget, gpointer data)
 {
    g_return_if_fail(cur_file != NULL);
-   widget = gnome_run_cmd_new("Run Command...", "Command: ");
+   widget = gnome_run_cmd_new(_("Run Command..."), _("Command: "));
    gtk_signal_connect(GTK_OBJECT(GNOME_RUN_CMD(widget)->run_button), "clicked", GTK_SIGNAL_FUNC(runcmd_cb_continue), widget);
    gtk_signal_connect_object(GTK_OBJECT(GNOME_RUN_CMD(widget)->run_button), "clicked", GTK_SIGNAL_FUNC(gtk_widget_destroy), GTK_OBJECT(widget));
    gtk_signal_connect_object(GTK_OBJECT(GNOME_RUN_CMD(widget)->cancel_button), "clicked", GTK_SIGNAL_FUNC(gtk_widget_destroy), GTK_OBJECT(widget));
@@ -311,8 +399,8 @@ static void runcmd_cb_continue(GtkWidget *widget, GnomeRunCmd *grc)
 
    if(!(exec = popen(string, "r")))
    {
-      perror("Error opening process!");
-      generic_dialog_with_text("Process could not be opened.");
+      perror(_("Error opening process!"));
+      generic_dialog_with_text(_("Process could not be opened."));
       g_print("\a");
       return;
    }
@@ -329,7 +417,7 @@ static void runcmd_cb_continue(GtkWidget *widget, GnomeRunCmd *grc)
 void indent_cb(GtkWidget *widget, gpointer data)
 {
    g_return_if_fail(cur_file != NULL);
-   widget = gnome_run_cmd_new("Indent...", "Indent: ");
+   widget = gnome_run_cmd_new(_("Indent..."), _("Indent: "));
    gtk_signal_connect(GTK_OBJECT(GNOME_RUN_CMD(widget)->run_button), "clicked", GTK_SIGNAL_FUNC(indent_cb_continue), widget);
    gtk_signal_connect_object(GTK_OBJECT(GNOME_RUN_CMD(widget)->run_button), "clicked", GTK_SIGNAL_FUNC(gtk_widget_destroy), GTK_OBJECT(widget));
    gtk_signal_connect_object(GTK_OBJECT(GNOME_RUN_CMD(widget)->cancel_button), "clicked", GTK_SIGNAL_FUNC(gtk_widget_destroy), GTK_OBJECT(widget));
@@ -340,6 +428,7 @@ void indent_cb(GtkWidget *widget, gpointer data)
 
 static void indent_cb_continue(GtkWidget *widget, GnomeRunCmd *grc)
 {
+   GnomeVFSURI *uri;
    gchar *string;
    FILE *exec;
    FILE *file;
@@ -371,8 +460,8 @@ static void indent_cb_continue(GtkWidget *widget, GnomeRunCmd *grc)
    full_string = g_strconcat("indent ", string, " ", temp_file, NULL);
    if(!(exec = popen(full_string, "r")))
    {
-      perror("Error opening process!");
-      generic_dialog_with_text("Indent process could not be opened.");
+      perror(_("Error opening process!"));
+      generic_dialog_with_text(_("Indent process could not be opened."));
       g_print("\a");
       g_free(full_string);
       return;
@@ -382,7 +471,9 @@ static void indent_cb_continue(GtkWidget *widget, GnomeRunCmd *grc)
    gtk_extext_freeze(extext);
    gtk_extext_delete_text(extext, start, end);
    gtk_extext_set_position(extext, start);
-   open_file_add_text(cur_file->text, temp_file);
+   uri = gnome_vfs_uri_new(temp_file);
+   open_file_full(cur_file, uri);
+   gnome_vfs_uri_unref(uri);
    remove(temp_file);
    gtk_extext_thaw(extext);
 }
