@@ -7,7 +7,7 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
@@ -23,7 +23,7 @@ extern "C" {
 
 #include "declarations.h"
 #include "widgets/gdsfile.h"
-#include "widgets/gnomefilelist.h"
+#include "widgets/gnome-file-selector.h"
 #include "widgets/gnomeasciilist.h"
 #include "widgets/gnomeruncmd.h"
 
@@ -35,6 +35,10 @@ void insert_email(GtkWidget *widget, gpointer data);
 void insert_gpl_notice(GtkWidget *widget, gpointer data);
 void insert_gpl_noticepp(GtkWidget *widget, gpointer data);
 void insert_gpl_noticepython(GtkWidget *widget, gpointer data);
+void insert_lgpl_notice(GtkWidget *widget, gpointer data);
+void insert_lgpl_noticepp(GtkWidget *widget, gpointer data);
+void insert_lgpl_noticepython(GtkWidget *widget, gpointer data);
+
 void insert_changelog_string(GtkWidget *widget, gpointer data);
 void insert_comment(GtkWidget *widget, gpointer data);
 void insert_commentpp(GtkWidget *widget, gpointer data);
