@@ -7,7 +7,7 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
@@ -57,7 +57,7 @@ void autoexec_script(void)
 {
    gchar filename[256];
    FILE* autoexec_file;
-   g_snprintf(filename, sizeof(filename), "%s/." PACKAGE "/autoexec.py", getenv("HOME"));
+   g_snprintf(filename, sizeof(filename), "%s/." PACKAGE "/autoexec.py", g_get_home_dir());
    if((autoexec_file = fopen(filename,"r")))
    {
       PyRun_SimpleFile(autoexec_file, "autoexec.py");
@@ -176,7 +176,7 @@ void build_scripts_menu(void)
    gchar path[384];
    g_snprintf(path, sizeof(path), PREFIX "/share/" PACKAGE "/scripts");
    build_menu_from_scripts_dir(path, "_Scripts/");
-   g_snprintf(path, sizeof(path), "%s/." PACKAGE "/scripts", getenv("HOME"));
+   g_snprintf(path, sizeof(path), "%s/." PACKAGE "/scripts", g_get_home_dir());
    build_menu_from_scripts_dir(path, "_Scripts/");
    return;
 }
@@ -186,7 +186,7 @@ void build_scripts_menu(void)
 void script_run_cb(GtkWidget *widget, gchar *filename)
 {
    FILE *file;
-   g_print("Executing Python script: %s\n", filename);
+   g_print(_("Executing Python script: %s\n"), filename);
    file = fopen(filename, "r");
    if(!file) return;
    PyRun_SimpleFile(file, filename);
