@@ -1,37 +1,79 @@
-#include <gdk/gdkprivate.h>
+/*  Glimmer - main.c
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ */
+
+#include <sys/wait.h>
+
 #include "declarations.h"
-#include "dragndrop.h"
-#include "session-management.h"
-#include "macro-language.h"
+#include "main.h"
+#include "build.h"
 #include "commandbar.h"
+#include "dialogs.h"
+#include "dragndrop.h"
+#include "file-io.h"
 #include "findbar.h"
-#include "linebar.h"
+#include "getprefs.h"
 #include "highlightbar.h"
-#include "view.h"
+#include "linebar.h"
+#include "macro-language.h"
+#include "menus.h"
+#include "mdi-routines.h"
+#include "misc.h"
+#include "searches.h"
+#include "session.h"
+#include "session-management.h"
+#include "settings.h"
 #include "signals.h"
+#include "splash.h"
+#include "syntax-highlight.h"
+#include "toolbar.h"
+#include "view.h"
+#include "widgets/gdstearaway.h"
 #include "xpm/bookmark.xpm"
 
-GtkWidget *app;
-GtkWidget *window;
-GtkWidget *appbar;
-GtkWidget *whole_window_box;
+#include <libgnomevfs/gnome-vfs-init.h>
+#include <libgnomevfs/gnome-vfs-types.h>
+#include <libgnomevfs/gnome-vfs-ops.h>
+
+GtkWidget *app = NULL;
+GtkWidget *window = NULL;
+GtkWidget *appbar = NULL;
+GtkWidget *whole_window_box = NULL;
+GtkWidget *hpaned1 = NULL;
+GtkWidget *vpaned2 = NULL;
+GtkWidget *hpaned3 = NULL;
+GtkWidget *vpaned4 = NULL;
+GtkWidget *panedbook1 = NULL;
+GtkWidget *panedbook2 = NULL;
+GtkWidget *panedbook3 = NULL;
+GtkWidget *panedbook4 = NULL;
+GHashTable *child_hash = NULL;
 GtkWidget *main_window_box;
-GtkWidget *box;
-GtkWidget *switch_label;
-GtkWidget *paned;
 GtkWidget *edit_box;
 GtkWidget *files_book;
-GtkWidget *file_selector;
 GtkStyle *extext_style = NULL;
-GtkAccelGroup *accel_group;
-GdkPixmap *bookmark_pixmap;
-GdkBitmap *bookmark_bitmap;
+GtkAccelGroup *accel_group = NULL;
+GnomePixmap *bookmark_pixmap = NULL;
 GList *files_list = NULL;
 GdsFile *cur_file = NULL;
 gint cur_page = -1;
 gint total_files = 0;
-static gchar *input_file = NULL, *input_session = NULL;
-gint line = 0;
+static gchar *input_file = NULL;
+static gchar *input_session = NULL;
+static gint line = 0;
+static gboolean none = FALSE;
 
 poptContext pctx;
 gchar** args;
@@ -51,41 +93,65 @@ struct poptOption options[] =
       0, N_("Jump to a line in the file specified by -f."),
       NULL
    },
+   {
+      "none", 'n', POPT_ARG_NONE, &none,
+      1, N_("Don't open any files."),
+      NULL
+   },
    {
       NULL, '\0', 0, NULL, 0, NULL, NULL
    }
 };
 
+static SplashScreen *splash;
+
 int main(int argc, char *argv[])
 {
    GtkWidget *text_widget;
    GtkWidget *win;
    GtkWidget *menu;
    GdkFont *font;
-   directory_check();
-
+   
 #ifdef ENABLE_NLS
    bindtextdomain(PACKAGE, GNOMELOCALEDIR);
    textdomain(PACKAGE);
 #endif
-
    gnome_init_with_popt_table(PACKAGE, PACKAGE " v" VERSION, argc, argv, options, 0, &pctx);
+   if(!gnome_vfs_initialized()) gnome_vfs_init();
+   directory_check();
+   splash = splash_screen_build("Glimmer  v" VERSION "\nBy Chris Phelps", PREFIX "/share/pixmaps/glimmer-splash.png");
+   splash_screen_append_icon(splash, GNOME_STOCK_PIXMAP_PREFERENCES);
+   splash_screen_append_icon(splash, GNOME_STOCK_PIXMAP_INDEX);
+   splash_screen_append_icon(splash, GNOME_STOCK_PIXMAP_COLORSELECTOR);
+   splash_screen_append_icon(splash, GNOME_STOCK_PIXMAP_FONT);
+#ifdef WITH_PYTHON
+   splash_screen_append_icon(splash, GNOME_STOCK_PIXMAP_EXEC);
+#endif
+   splash_screen_append_icon(splash, GNOME_STOCK_PIXMAP_OPEN);
+   gtk_widget_show_all(splash->window);
+   splash_screen_update(splash, _("Retrieving preferences..."));
    get_prefs();
-   app = gnome_app_new(PACKAGE, VERSION);
+   // Set the prefs icon sensitive
+   splash_screen_update_next_icon(splash);
+   splash_screen_update(splash, _("Initializing main application..."));
+   app = gnome_app_new(PACKAGE, "Glimmer v" VERSION);
    gtk_container_set_border_width(GTK_CONTAINER(app), 0);
    gtk_window_set_policy(GTK_WINDOW(app), TRUE, TRUE, FALSE);
-   gtk_signal_connect(GTK_OBJECT(app), "focus_in_event", GTK_SIGNAL_FUNC(main_window_focused), NULL);
+   gnome_app_enable_layout_config(GNOME_APP(app), TRUE);
    gtk_signal_connect(GTK_OBJECT(app), "delete_event", GTK_SIGNAL_FUNC(pre_exit), NULL);
    window = app;
-   
+
    appbar = gnome_appbar_new(FALSE, TRUE, GNOME_PREFERENCES_ALWAYS);
    gnome_appbar_set_default(GNOME_APPBAR(appbar), "Ready.");
    gnome_app_set_statusbar(GNOME_APP(app), appbar);
    gtk_widget_show(appbar);
 
+   splash_screen_update(splash, _("Building menus and toolbars..."));
    make_menus();
    make_toolbars();
+#ifdef WITH_PYTHON
    make_command_combo();
+#endif
    make_find_toolbar();
    make_line_toolbar();
    init_session_management();
@@ -93,15 +159,44 @@ int main(int argc, char *argv[])
 
    menu = build_highlight_menu();
    make_highlight_bar(menu);
+   // Set the menus icon sensitive
+   splash_screen_update_next_icon(splash);
 
    whole_window_box = gtk_vbox_new(FALSE, 0);
-   gtk_container_set_border_width(GTK_CONTAINER(whole_window_box), 0);
+   gtk_container_set_border_width(GTK_CONTAINER(whole_window_box), 2);
    gnome_app_set_contents(GNOME_APP(window), whole_window_box);
    gtk_widget_show(whole_window_box);
 
+   hpaned3 = gtk_hpaned_new();
+   gtk_paned_set_handle_size(GTK_PANED(hpaned3), 0);
+   gtk_paned_set_gutter_size(GTK_PANED(hpaned3), 0);
+   gtk_box_pack_start(GTK_BOX(whole_window_box), hpaned3, TRUE, TRUE, 0);
+   gtk_widget_show(hpaned3);
+
+   hpaned1 = gtk_hpaned_new();
+   gtk_paned_set_handle_size(GTK_PANED(hpaned1), 0);
+   gtk_paned_set_gutter_size(GTK_PANED(hpaned1), 0);
+   gtk_paned_add1(GTK_PANED(hpaned3), hpaned1);
+   gtk_widget_show(hpaned1);
+
+   vpaned4 = gtk_vpaned_new();
+   gtk_paned_set_handle_size(GTK_PANED(vpaned4), 0);
+   gtk_paned_set_gutter_size(GTK_PANED(vpaned4), 0);
+   gtk_paned_add2(GTK_PANED(hpaned1), vpaned4);
+   gtk_widget_show(vpaned4);
+
+   vpaned2 = gtk_vpaned_new();
+   gtk_paned_set_handle_size(GTK_PANED(vpaned2), 0);
+   gtk_paned_set_gutter_size(GTK_PANED(vpaned2), 0);
+   gtk_paned_add1(GTK_PANED(vpaned4), vpaned2);
+   gtk_widget_show(vpaned2);
+
+   // Initialize the hash of children
+   child_hash = g_hash_table_new(g_str_hash, g_str_equal);
+
    main_window_box = gtk_hbox_new(FALSE, 0);
    gtk_container_set_border_width(GTK_CONTAINER(main_window_box), 0);
-   gtk_box_pack_start(GTK_BOX(whole_window_box), main_window_box, TRUE, TRUE, 0);
+   gtk_paned_add2(GTK_PANED(vpaned2), main_window_box);
    gtk_widget_show(main_window_box);
 
    edit_box = gtk_hbox_new(FALSE, 0);
@@ -113,8 +208,8 @@ int main(int argc, char *argv[])
    files_book = gtk_notebook_new();
    gtk_box_pack_end(GTK_BOX(edit_box), files_book, TRUE, TRUE, 0);
    gtk_notebook_set_scrollable(GTK_NOTEBOOK(files_book), TRUE);
-   gtk_notebook_popup_enable(GTK_NOTEBOOK(files_book));
    gtk_signal_connect(GTK_OBJECT(files_book), "switch_page", GTK_SIGNAL_FUNC(set_notebook_page), NULL);  
+   gtk_signal_connect(GTK_OBJECT(files_book), "focus_in_event", GTK_SIGNAL_FUNC(main_window_focused), NULL);
    gtk_widget_show(files_book);
    if(general_preferences.notebook_tab_position >= 4)
    {
@@ -123,9 +218,10 @@ int main(int argc, char *argv[])
    else
    {
       gtk_notebook_set_show_tabs(GTK_NOTEBOOK(files_book), TRUE);
-      gtk_notebook_set_tab_pos(GTK_NOTEBOOK(files_book), (GtkPositionType) general_preferences.notebook_tab_position);
+      gtk_notebook_set_tab_pos(GTK_NOTEBOOK(files_book),(GtkPositionType) general_preferences.notebook_tab_position);
    }
 
+   splash_screen_update(splash, _("Initializing colors..."));
    /* This is a way ugly hack */
    win = gtk_window_new(GTK_WINDOW_DIALOG);   
    text_widget = gtk_text_new(0, 0);
@@ -138,12 +234,13 @@ int main(int argc, char *argv[])
    {
       extext_style->text[GTK_STATE_NORMAL] = general_preferences.fg;
       extext_style->bg[GTK_STATE_NORMAL] = general_preferences.bg;
-      extext_style->bg[GTK_STATE_PRELIGHT] = general_preferences.bm_bg;
       extext_style->bg[GTK_STATE_SELECTED] = general_preferences.s_bg;
+      extext_style->bg[GTK_STATE_PRELIGHT] = general_preferences.bm_bg;
+      extext_style->bg[GTK_STATE_INSENSITIVE] = general_preferences.gutter_bg;
       HighlightCache.colors[DEFAULT] = general_preferences.fg;
       if(strlen(general_preferences.pixmap_name))
       {
-         general_preferences.bg_pixmap = (GnomePixmap *)gnome_pixmap_new_from_file(general_preferences.pixmap_name);
+         general_preferences.bg_pixmap =(GnomePixmap *)gnome_pixmap_new_from_file(general_preferences.pixmap_name);
          if(general_preferences.bg_pixmap) extext_style->bg_pixmap[GTK_STATE_NORMAL] = general_preferences.bg_pixmap->pixmap;
       }
       else
@@ -152,6 +249,9 @@ int main(int argc, char *argv[])
    gtk_style_attach(extext_style, text_widget->window);
    gtk_widget_destroy(win);
 
+   // Set the colors icon sensitive
+   splash_screen_update_next_icon(splash);
+   splash_screen_update(splash, _("Initializing fonts..."));
    if((font = gdk_font_load(general_preferences.font_name)))
    {
       gdk_font_unref(extext_style->font);
@@ -234,7 +334,13 @@ int main(int argc, char *argv[])
    get_saved_colors();
    gds_file_set_global_props(general_preferences.undo_max, general_preferences.use_spaces ? general_preferences.spaces : 0, general_preferences.auto_indent, general_preferences.bracketmatch, general_preferences.tab_stops);
 
+   // Set the font icon sensitive
+   splash_screen_update_next_icon(splash);
+
    // we need to initialize python
+#ifdef WITH_PYTHON
+   splash_screen_update(splash, _("Starting Python..."));
+#endif
    initialize_macro_language(argc, argv);
    return(0);
 }
@@ -242,10 +348,21 @@ int main(int argc, char *argv[])
 void main_finish(void *closure, int argc, char *argv[])
 {
    gint files_opened;
-   args = (gchar **)poptGetArgs(pctx);
+   gchar *path;
+   gchar *file;
+   gchar *full;
+   gchar cwd[256];
+   args =(gchar **)poptGetArgs(pctx);
 
+#ifdef WITH_PYTHON
    build_scripts_menu();
+   splash_screen_update(splash, _("Running Python autoexec..."));
    autoexec_script();
+   // Set the python icon sensitive
+   splash_screen_update_next_icon(splash);
+#endif
+
+   splash_screen_update(splash, _("Opening files..."));
    if(input_session)
    {
       if(check_if_file_exists(input_session))
@@ -253,15 +370,14 @@ void main_finish(void *closure, int argc, char *argv[])
          files_opened = open_session_from_file(input_session);
          if(files_opened)
          {
-            gchar *path, *file, *full, cwd[256];
-            g_free(session_file);
+            if(session_file) g_free(session_file);
             getcwd(cwd, sizeof(cwd));
             path = get_path_from_filename(input_session);
             file = get_file_from_filename(input_session);
             if(!path) full = g_strconcat(cwd, "/", file, NULL);
             else full = g_strconcat(path, "/", file, NULL);
-            g_free(path);
-            g_free(file);
+            if(path) g_free(path);
+            if(file) g_free(file);
             session_file = full;
          }
          else
@@ -272,9 +388,18 @@ void main_finish(void *closure, int argc, char *argv[])
    }
    if(input_file)
    {
-      if(check_if_file_exists(input_file))
+      gchar *path, *file, *full, cwd[256];
+      getcwd(cwd, sizeof(cwd));
+      path = get_path_from_filename(input_file);
+      file = get_file_from_filename(input_file);
+      if(!path) full = g_strconcat(cwd, "/", file, NULL);
+      else full = g_strconcat(path, "/", file, NULL);
+      if(path) g_free(path);
+      if(file) g_free(file);
+      if(check_if_file_exists(full))
       {
-         open_file_real(input_file);
+         open_file_real(full);
+         g_free(full);
          if(line <= GTK_EXTEXT(cur_file->text)->line_count && line > 0)
             gtk_extext_set_line(GTK_EXTEXT(cur_file->text), line);
       }
@@ -283,17 +408,25 @@ void main_finish(void *closure, int argc, char *argv[])
          g_error("File: %s could not be opened, or does not exist.\n", input_file);
       }
    }
-   if(!g_list_length(files_list) && args)
+   if(!g_list_length(files_list) && !none && args)
    {
       int i = 0;
+      getcwd(cwd, sizeof(cwd));
+      path = get_path_from_filename(args[i]);
+      file = get_file_from_filename(args[i]);
+      if(!path) full = g_strconcat(cwd, "/", file, NULL);
+      else full = g_strconcat(path, "/", file, NULL);
+      if(path) g_free(path);
+      if(file) g_free(file);
       while(args[i])
       {
-         if(check_if_file_exists((gchar *)args[i]))
-            open_file_real((gchar *)args[i]);
+         if(check_if_file_exists(full))
+            open_file_real(full);
+         g_free(full);
          i++;
       }
    }
-   if(!g_list_length(files_list))
+   if(!g_list_length(files_list) && !none)
    {
       if(!get_last_session() && general_preferences.untitled)
          new_file_cb(NULL, NULL);
@@ -301,8 +434,10 @@ void main_finish(void *closure, int argc, char *argv[])
    poptFreeContext(pctx);
    setup_recent_files_list(general_preferences.history);
    adjust_sensitivity();
+   splash_screen_update_next_icon(splash);
+   splash_screen_die(splash);
    gtk_widget_show(window);
-   bookmark_pixmap = gdk_pixmap_create_from_xpm_d(app->window, &bookmark_bitmap, NULL, bookmark_xpm);
+   bookmark_pixmap = (GnomePixmap *)gnome_pixmap_new_from_xpm_d((char **)bookmark_xpm);
    init_view_settings();
    if(general_preferences.geometry)
    {
@@ -321,8 +456,10 @@ void file_change(GtkWidget *widget, GdsFile *new_file)
          gint index, old_page;
          old_page = cur_page;
          index = get_nth_file_number(new_file);
+#ifdef WITH_PYTHON
          if(index == cur_page && cur_file != new_file)
             file_emit_scripting_signal("focus-out", cur_file);
+#endif
          gtk_notebook_set_page(GTK_NOTEBOOK(files_book), index);
          if(cur_file != new_file)
          {
@@ -331,55 +468,73 @@ void file_change(GtkWidget *widget, GdsFile *new_file)
       }
       else
       {
+#ifdef WITH_PYTHON
          if(cur_file && cur_file != new_file)
          {
             file_emit_scripting_signal("focus-out", cur_file);
          }
+#endif
          if(cur_file != new_file)
          {
             cur_file = new_file;
+#ifdef WITH_PYTHON
             file_emit_scripting_signal("focus-in", cur_file);
             app_emit_scripting_signal("change-file");
+#endif
          }
          gtk_widget_grab_focus(cur_file->text);
       }
-      if(cur_file->modtime > 0 && cur_file->modtime < get_time(cur_file->filename))
-      {
-         file_externally_modified_reload(cur_file->filename, cur_file, GTK_SIGNAL_FUNC(reload_file_cb), NULL);
-         cur_file->modtime = get_time(cur_file->filename);
-      }
    }
    else
    {
+#ifdef WITH_PYTHON
       if(cur_file) file_emit_scripting_signal("focus-out", cur_file);
+#endif
       cur_file = new_file;
+#ifdef WITH_PYTHON
       app_emit_scripting_signal("change-file");
+#endif
+   }
+   if(cur_file && cur_file->modtime > 0 && cur_file->modtime < get_time(cur_file->uri))
+   {
+      file_externally_modified_reload(cur_file->filename, cur_file, GTK_SIGNAL_FUNC(reload_file_cb), NULL);
+      cur_file->modtime = get_time(cur_file->uri);
    }
    set_window_title();
    adjust_sensitivity();
+#ifdef WITH_PYTHON
    adjust_popup_menu();
+#endif
 }
 
 void set_notebook_page(GtkNotebook *notebook, GtkNotebookPage *page, guint page_num, gpointer data)
 {
+#ifdef WITH_PYTHON
    file_emit_scripting_signal("focus-out", cur_file);
+#endif
    cur_page = page_num;
    cur_file = get_nth_file_proper(page_num);
    if(cur_file)
    {
       gtk_widget_grab_focus(cur_file->text);
+#ifdef WITH_PYTHON
       file_emit_scripting_signal("focus-in", cur_file);
-      if(cur_file->modtime > 0 && cur_file->modtime < get_time(cur_file->filename))
+#endif
+      if(cur_file->modtime > 0 && cur_file->modtime < get_time(cur_file->uri))
       {
          file_externally_modified_reload(cur_file->filename, cur_file, GTK_SIGNAL_FUNC(reload_file_cb), NULL);
-         cur_file->modtime = get_time(cur_file->filename);
+         cur_file->modtime = get_time(cur_file->uri);
       }
    }
+#ifdef WITH_PYTHON
    app_emit_scripting_signal("change-file");
+#endif
    file_pos_changed(NULL, 0, NULL);
    set_window_title();
    adjust_sensitivity();   
+#ifdef WITH_PYTHON
    adjust_popup_menu();
+#endif
 }
 
 void set_window_title(void)
@@ -406,34 +561,31 @@ void set_window_title(void)
 void adjust_sensitivity(void)
 {
    GtkExText *text;
-   GtkEditable *editable;
    gchar cur_char;
-   GSList *cur = NULL;
+   GList *cur = NULL;
    GtkWidget *w;
    gchar *filename;
    gchar *compare;
-   GSList *first;
-   gint counter = 0;
+    gint counter = 0;
 
-   if(cur_file != NULL)
+   if(cur_file && !cur_file->xfering)
    {
-      editable = GTK_EDITABLE(cur_file->text);
       text = GTK_EXTEXT(cur_file->text);
-      cur_char = GTK_EXTEXT_INDEX(text, editable->current_pos);
+      cur_char = GTK_EXTEXT_INDEX(text, text->current_pos);
 
-      gtk_widget_set_sensitive(file_menu_revert, TRUE);
-      gtk_widget_set_sensitive(file_menu_close, TRUE);
-      gtk_widget_set_sensitive(filebar_close, TRUE);   
-      gtk_widget_set_sensitive(file_menu_close_all, TRUE);
       gtk_widget_set_sensitive(file_menu_save, TRUE);
       gtk_widget_set_sensitive(filebar_save, TRUE);   
       gtk_widget_set_sensitive(file_menu_saveas, TRUE);
       gtk_widget_set_sensitive(filebar_saveas, TRUE);
       gtk_widget_set_sensitive(file_menu_save_all, TRUE);
+      gtk_widget_set_sensitive(file_menu_revert, TRUE);
+      gtk_widget_set_sensitive(file_menu_close, TRUE);
+      gtk_widget_set_sensitive(filebar_close, TRUE);   
+      gtk_widget_set_sensitive(file_menu_close_all, TRUE);
 
       gtk_widget_set_sensitive(editmenu, TRUE);
       gtk_widget_set_sensitive(searchmenu, TRUE);
-      if(!text->read_only)
+      if(text->editable)
          gtk_widget_set_sensitive(insertmenutitle, TRUE);
       else
          gtk_widget_set_sensitive(insertmenutitle, FALSE);
@@ -455,7 +607,7 @@ void adjust_sensitivity(void)
          gtk_widget_set_sensitive(windows_menu_next, TRUE);
          for(temp = g_list_first(files_list); temp; temp = temp->next)
          {
-            current = (GdsFile *)temp->data;
+            current =(GdsFile *)temp->data;
             if(GDS_TEAR_AWAY(current->tear_away)->torn)
                torn++;
          }
@@ -477,9 +629,26 @@ void adjust_sensitivity(void)
          gtk_widget_set_sensitive(windows_menu_moveprev, FALSE);
          gtk_widget_set_sensitive(windows_menu_movenext, FALSE);
       }
+#ifdef WITH_PYTHON
+      if(panedbook1 && g_list_length(GTK_NOTEBOOK(panedbook1)->children) > 1)
+      {
+         gtk_widget_set_sensitive(windows_paned_left, TRUE);
+         gtk_widget_set_sensitive(windows_paned_right, TRUE);
+      }
+      else
+      {
+         gtk_widget_set_sensitive(windows_paned_left, FALSE);
+         gtk_widget_set_sensitive(windows_paned_right, FALSE);
+      }
+      if(panedbook1 && g_list_length(GTK_NOTEBOOK(panedbook1)->children) > 0)
+         gtk_widget_set_sensitive(windows_focus_paned, TRUE);
+      else
+         gtk_widget_set_sensitive(windows_focus_paned, FALSE);
+#endif
+      gtk_widget_set_sensitive(windows_focus_file, TRUE);
+
       gtk_widget_set_sensitive(findbar, TRUE);
       gtk_widget_set_sensitive(buildbar, TRUE);
-      set_build_sensitivity();
       gtk_widget_set_sensitive(highlightbar, TRUE);
       if(cur_file->tables && cur_file->tables->filename)
       {
@@ -491,36 +660,32 @@ void adjust_sensitivity(void)
          gtk_widget_set_sensitive(rehighlight_button, FALSE);
          compare = "none";
       }
-      first = g_slist_copy(highlight_options);
-      first = cur = g_slist_reverse(first);
+      cur = highlight_options;
       for(counter = 0; cur; cur = cur->next, counter++)
       {
          w = GTK_WIDGET(cur->data);
-         filename = (gchar *)gtk_object_get_data(GTK_OBJECT(w), "filename");
+         filename =(gchar *)gtk_object_get_data(GTK_OBJECT(w), "filename");
          if(!strcmp(compare, filename))
          {
-            GTK_CHECK_MENU_ITEM(w)->active = TRUE;
             gtk_option_menu_set_history(GTK_OPTION_MENU(highlightbar_option), counter);
             gtk_widget_queue_draw(w);
-         }
-         else
-         {
-            GTK_CHECK_MENU_ITEM(w)->active = FALSE;
+            break;
          }
       }
-      g_slist_free(first);
    }
    else
    {
       gtk_widget_set_sensitive(file_menu_revert, FALSE);
-      gtk_widget_set_sensitive(file_menu_close, FALSE);
-      gtk_widget_set_sensitive(file_menu_close_all, FALSE);
-      gtk_widget_set_sensitive(filebar_close, FALSE);   
       gtk_widget_set_sensitive(file_menu_save, FALSE);
       gtk_widget_set_sensitive(filebar_save, FALSE);   
       gtk_widget_set_sensitive(file_menu_saveas, FALSE);
       gtk_widget_set_sensitive(filebar_saveas, FALSE);   
       gtk_widget_set_sensitive(file_menu_save_all, FALSE);
+      gtk_widget_set_sensitive(file_menu_close, FALSE);
+      gtk_widget_set_sensitive(file_menu_close_all, FALSE);
+      gtk_widget_set_sensitive(filebar_close, FALSE);   
+      gtk_widget_set_sensitive(file_menu_print, FALSE);
+      gtk_widget_set_sensitive(file_menu_print_preview, FALSE);
       
       gtk_widget_set_sensitive(editmenu, FALSE);
       gtk_widget_set_sensitive(searchmenu, FALSE);
@@ -533,37 +698,41 @@ void adjust_sensitivity(void)
       gtk_widget_set_sensitive(editbar_copy, FALSE);
       gtk_widget_set_sensitive(editbar_paste, FALSE);
       gtk_widget_set_sensitive(editbar_properties, FALSE);
+
       gtk_widget_set_sensitive(windows_menu_prev, FALSE);
       gtk_widget_set_sensitive(windows_menu_next, FALSE);
+      gtk_widget_set_sensitive(windows_menu_moveprev, FALSE);
+      gtk_widget_set_sensitive(windows_menu_movenext, FALSE);
+
+#ifdef WITH_PYTHON
+      gtk_widget_set_sensitive(windows_paned_left, FALSE);
+      gtk_widget_set_sensitive(windows_paned_right, FALSE);
+      gtk_widget_set_sensitive(windows_focus_paned, FALSE);
+#endif
+      gtk_widget_set_sensitive(windows_focus_file, FALSE);
+
       gtk_widget_set_sensitive(findbar, FALSE);
       gtk_widget_set_sensitive(buildbar, FALSE);
 
       gtk_option_menu_set_history(GTK_OPTION_MENU(highlightbar_option), 0);
       gtk_widget_set_sensitive(highlightbar, FALSE);
    }
+   set_build_sensitivity();
 }
 
 void directory_check(void)
 {
-   gchar buffer[384];
-   gboolean exists;
+   gchar *path;
 
-   g_snprintf(buffer, sizeof(buffer), "%s/." PACKAGE "/session.last", getenv("HOME"));
-   session_file = g_strdup(buffer);
-   exists = check_if_file_exists(buffer);
-   if(exists) return;
-   g_snprintf(buffer, sizeof(buffer), "mkdir %s/." PACKAGE, getenv("HOME"));
-   g_print(_("Creating ~/" PACKAGE " directory.\n"));
-   system(buffer);
-
-   g_snprintf(buffer, sizeof(buffer), "%s/." PACKAGE "/session.last", getenv("HOME"));
-   g_print(_("Creating ~/." PACKAGE "/session.last file.\n"));
-   file_create(NULL, buffer);
-
-   g_snprintf(buffer, sizeof(buffer), "mkdir %s/." PACKAGE "/languages", getenv("HOME"));
-   g_print(_("Creating ~/." PACKAGE "/languages directory.\n"));
-   system(buffer);
-   return;
+   path = g_strconcat(g_get_home_dir(), "/." PACKAGE, NULL);
+   if(!check_if_dir_exists(path))
+   {
+      gnome_vfs_make_directory(path, GNOME_VFS_PERM_USER_ALL | GNOME_VFS_PERM_GROUP_ALL | GNOME_VFS_PERM_OTHER_READ | GNOME_VFS_PERM_OTHER_EXEC);
+   }
+   g_free(path);
+   path = g_strconcat(g_get_home_dir(), "/." PACKAGE, "/session.last", NULL);   
+   if(!check_if_file_exists(path)) create_file(path);
+   session_file = path;
 }
 
 void kill_widget(GtkWidget *widget, GtkWidget *target)
@@ -593,8 +762,8 @@ void try_exit(GtkWidget *widget, gpointer data)
    
    for(i = total_files-1; i >= 0; i--)
    {
-      file = (GdsFile *)g_list_nth_data(files_list, i);
-      if(gds_editor_changed(GDS_EDITOR(file->text)) && strstr(file->filename, "Untitled"))
+      file =(GdsFile *)g_list_nth_data(files_list, i);
+      if(gds_editor_changed(GDS_EDITOR(file->text)) && gds_file_is_untitled(file))
       {
          gint val = 0;
          file_change(widget, file);
@@ -640,19 +809,18 @@ void try_exit(GtkWidget *widget, gpointer data)
    gtk_main_quit();
 }
 
-void main_window_focused(GtkWidget *widget, gpointer data)
+void main_window_focused(GtkWidget *widget, GdkEventFocus *event, gpointer data)
 {
    gint total_pages;
    GdsFile *new_file = NULL;
-   total_pages = (gint)g_list_length(GTK_NOTEBOOK(files_book)->children); // max page number
+   total_pages =(gint)g_list_length(GTK_NOTEBOOK(files_book)->children); // max page number
    if(cur_page >= 0 && cur_page < total_pages-1)
    {
       new_file = get_nth_file_proper(cur_page);
-      file_change(widget, new_file);
-   }  
+   }
    else if(total_pages > 0)
    {
       new_file = get_nth_file_proper(total_pages-1);
-      file_change(widget, new_file);
    }
+   if(cur_file != new_file) file_change(widget, new_file);
 }
