@@ -7,7 +7,7 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
@@ -26,6 +26,7 @@
 #include "main.h"
 #include "macro-language.h"
 #include "misc.h"
+#include "open-remote-file.h"
 #include "properties.h"
 #include "searches.h"
 #include "settings.h"
@@ -35,11 +36,79 @@
 #include "view.h"
 #include "libprint/print.h"
 
-#include "xpm/selection.xpm"
+#include "xpm/new_menu.xpm"
+#include "xpm/open_menu.xpm"
+#include "xpm/revert_menu.xpm"
+#include "xpm/close_menu.xpm"
+#include "xpm/close_all.xpm"
+#include "xpm/save_menu.xpm"
+#include "xpm/saveas_menu.xpm"
+#include "xpm/save_all.xpm"
+#include "xpm/print_menu.xpm"
+
+#include "xpm/bookmark_menu.xpm"
+#include "xpm/clear_menu.xpm"
 #include "xpm/select_all.xpm"
-#include "xpm/debug.xpm"
+#include "xpm/select_line.xpm"
+#include "xpm/selection.xpm"
+#include "xpm/rehighlight.xpm"
+#include "xpm/regenerate.xpm"
+#include "xpm/props_menu.xpm"
+
+#include "xpm/goto_line.xpm"
+#include "xpm/search_menu.xpm"
+#include "xpm/prev_bookmark.xpm"
+#include "xpm/next_bookmark.xpm"
+#include "xpm/bracket_match.xpm"
+
+#include "xpm/compile_menu.xpm"
+#include "xpm/debug_menu.xpm"
+#include "xpm/execute_menu.xpm"
+
+#include "xpm/prefs_menu.xpm"
+#include "xpm/colors_menu.xpm"
+
+#include "xpm/prev_file.xpm"
+#include "xpm/next_file.xpm"
+
 #include "xpm/window.xpm"
 
+#define GLIMMER_STOCK_PIXMAP_NEW "Glimmer_New"
+#define GLIMMER_STOCK_PIXMAP_OPEN "Glimmer_Open"
+#define GLIMMER_STOCK_PIXMAP_REVERT "Glimmer_Revert"
+#define GLIMMER_STOCK_PIXMAP_CLOSE "Glimmer_Close"
+#define GLIMMER_STOCK_PIXMAP_CLOSE_ALL "Glimmer_Close_All"
+#define GLIMMER_STOCK_PIXMAP_SAVE "Glimmer_Save"
+#define GLIMMER_STOCK_PIXMAP_SAVE_AS "Glimmer_Save_AS"
+#define GLIMMER_STOCK_PIXMAP_SAVE_ALL "Glimmer_Save_All"
+#define GLIMMER_STOCK_PIXMAP_PRINT "Glimmer_Print"
+
+#define GLIMMER_STOCK_PIXMAP_BOOKMARK "Glimmer_Bookmark"
+#define GLIMMER_STOCK_PIXMAP_CLEAR "Glimmer_Clear"
+#define GLIMMER_STOCK_PIXMAP_SELECTION "Glimmer_Selection"
+#define GLIMMER_STOCK_PIXMAP_SELECT_LINE "Glimmer_SelectLine"
+#define GLIMMER_STOCK_PIXMAP_SELECT_ALL "Glimmer_SelectAll"
+#define GLIMMER_STOCK_PIXMAP_REHIGHLIGHT "Glimmer_Rehighlight"
+#define GLIMMER_STOCK_PIXMAP_REGENERATE "Glimmer_Regenerate"
+#define GLIMMER_STOCK_PIXMAP_PROPS "Glimmer_Props"
+
+#define GLIMMER_STOCK_PIXMAP_GOTO_LINE "Glimmer_Goto_Line"
+#define GLIMMER_STOCK_PIXMAP_SEARCH "Glimmer_Search"
+#define GLIMMER_STOCK_PIXMAP_PREV_BOOKMARK "Glimmer_Prev_Bookmark"
+#define GLIMMER_STOCK_PIXMAP_NEXT_BOOKMARK "Glimmer_Next_Bookmark"
+#define GLIMMER_STOCK_PIXMAP_BRACKET_MATCH "Glimmer_Bracket_Match"
+
+#define GLIMMER_STOCK_PIXMAP_COMPILE "Glimmer_Compile"
+#define GLIMMER_STOCK_PIXMAP_DEBUG "Glimmer_Debug"
+#define GLIMMER_STOCK_PIXMAP_EXECUTE "Glimmer_Execute"
+
+#define GLIMMER_STOCK_PIXMAP_PREFS "Glimmer_Prefs"
+#define GLIMMER_STOCK_PIXMAP_COLORS "Glimmer_Colors"
+
+#define GLIMMER_STOCK_PIXMAP_WINDOW "Glimmer_Window"
+#define GLIMMER_STOCK_PIXMAP_PREV_FILE "Glimmer_Prev_File"
+#define GLIMMER_STOCK_PIXMAP_NEXT_FILE "Glimmer_Next_File"
+
 GtkWidget *filemenu;
 GtkWidget *recentmenu;
 GtkWidget *editmenu;
@@ -67,6 +136,8 @@ GtkWidget *file_menu_print_preview;
 GtkWidget *edit_menu_undo;
 GtkWidget *edit_menu_redo;
 GtkWidget *search_menu_match;
+GtkWidget *search_menu_highlight;
+GtkWidget *search_menu_select;
 GtkWidget *build_menu_compile;
 GtkWidget *build_menu_kill_compile;
 GtkWidget *build_menu_debug;
@@ -86,13 +157,20 @@ GtkWidget *windows_menu_prev;
 GtkWidget *windows_menu_next;
 GtkWidget *windows_menu_moveprev;
 GtkWidget *windows_menu_movenext;
+#ifdef WITH_PYTHON
+GtkWidget *windows_paned_left;
+GtkWidget *windows_paned_right;
+GtkWidget *windows_focus_paned;
+#endif
+GtkWidget *windows_focus_file;
+
 GtkWidget *edit_popup_menu;
 
 GnomeUIInfo session_menu[] = {
-   { GNOME_APP_UI_ITEM, _("_Save Current Session"), _("Save the current session"),(gpointer)save_session_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_SAVE, 'S',(GdkModifierType)(GDK_CONTROL_MASK | GDK_MOD1_MASK), 0 },
-   { GNOME_APP_UI_ITEM, _("Save Session _As..."), _("Save the current session with a different name"),(gpointer)save_session_as_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_SAVE_AS, 'A',(GdkModifierType)(GDK_CONTROL_MASK | GDK_MOD1_MASK), 0 },
+   { GNOME_APP_UI_ITEM, _("_Save Current Session"), _("Save the current session"),(gpointer)save_session_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_SAVE, 'S',(GdkModifierType)(GDK_CONTROL_MASK | GDK_MOD1_MASK), 0 },
+   { GNOME_APP_UI_ITEM, _("Save Session _As..."), _("Save the current session with a different name"),(gpointer)save_session_as_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_SAVE_AS, 'A',(GdkModifierType)(GDK_CONTROL_MASK | GDK_MOD1_MASK), 0 },
    GNOMEUIINFO_SEPARATOR,
-   { GNOME_APP_UI_ITEM, _("_Open Session..."), _("Open a session"),(gpointer)open_session_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_OPEN, 'O',(GdkModifierType)(GDK_CONTROL_MASK | GDK_MOD1_MASK), 0 },
+   { GNOME_APP_UI_ITEM, _("_Open Session..."), _("Open a session"),(gpointer)open_session_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_OPEN, 'O',(GdkModifierType)(GDK_CONTROL_MASK | GDK_MOD1_MASK), 0 },
    GNOMEUIINFO_END
 };
 
@@ -102,25 +180,25 @@ GnomeUIInfo recent_menu[] = {
 };
 
 GnomeUIInfo file_menu[] = {
-   { GNOME_APP_UI_ITEM, _("_New"), _("Create a new file."),(gpointer)new_file_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_NEW, 'N', GDK_CONTROL_MASK, 0 },
-   { GNOME_APP_UI_ITEM, _("_Open..."), _("Open a file."),(gpointer)open_file_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_OPEN, 'O', GDK_CONTROL_MASK, 0 },
-   { GNOME_APP_UI_ITEM, _("Open _Multiple..."), _("Open window with explicit close."),(gpointer)open_files_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_OPEN, 'O',(GdkModifierType)(GDK_CONTROL_MASK | GDK_SHIFT_MASK), NULL },
-   { GNOME_APP_UI_ITEM, _("_Revert"), _("Revert to saved file."),(gpointer)revert_current_file, NULL, NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_REVERT, 'R',(GdkModifierType)(GDK_CONTROL_MASK | GDK_SHIFT_MASK), 0 },
+   { GNOME_APP_UI_ITEM, _("_New"), _("Create a new file."),(gpointer)new_file_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_NEW, 'N', GDK_CONTROL_MASK, 0 },
+   { GNOME_APP_UI_ITEM, _("_Open..."), _("Open a file."),(gpointer)open_file_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_OPEN, 'O', GDK_CONTROL_MASK, 0 },
+   { GNOME_APP_UI_ITEM, _("_Open Remote..."), _("Open a file on another computer."),(gpointer)open_remote_file_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_OPEN, 'O', (GdkModifierType)GDK_CONTROL_MASK | GDK_SHIFT_MASK, 0 },
+   { GNOME_APP_UI_ITEM, _("_Revert"), _("Revert to saved file."),(gpointer)revert_file_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_REVERT, 'R',(GdkModifierType)(GDK_CONTROL_MASK | GDK_SHIFT_MASK), 0 },
    GNOMEUIINFO_SEPARATOR,
-   { GNOME_APP_UI_ITEM, _("_Save"), _("Save the current file."),(gpointer)save_file_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_SAVE, 'S', GDK_CONTROL_MASK, 0 },
-   { GNOME_APP_UI_ITEM, _("Save _As"), _("Save the current file."),(gpointer)save_file_as_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_SAVE_AS, 'A', GDK_CONTROL_MASK, 0 },
-   { GNOME_APP_UI_ITEM, _("Sa_ve All"), _("Save all open files"),(gpointer)save_all_files_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_SAVE, 'S',(GdkModifierType)(GDK_CONTROL_MASK | GDK_SHIFT_MASK), 0 },
+   { GNOME_APP_UI_ITEM, _("_Save"), _("Save the current file."),(gpointer)save_file_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_SAVE, 'S', GDK_CONTROL_MASK, 0 },
+   { GNOME_APP_UI_ITEM, _("Save _As"), _("Save the current file."),(gpointer)save_file_as_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_SAVE_AS, 'A', GDK_CONTROL_MASK, 0 },
+   { GNOME_APP_UI_ITEM, _("Sa_ve All"), _("Save all open files"),(gpointer)save_all_files_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_SAVE_ALL, 'S',(GdkModifierType)(GDK_CONTROL_MASK | GDK_SHIFT_MASK), 0 },
    GNOMEUIINFO_SEPARATOR,
-   { GNOME_APP_UI_ITEM, _("_Close"), _("Close the current file."),(gpointer)close_file_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_CLOSE, 'W', GDK_CONTROL_MASK, 0 },
-   { GNOME_APP_UI_ITEM, _("C_lose All"), _("Close all open files"),(gpointer)close_all_files_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_CLOSE, 'W',(GdkModifierType)(GDK_CONTROL_MASK | GDK_SHIFT_MASK), 0 },
+   { GNOME_APP_UI_ITEM, _("_Close"), _("Close the current file."),(gpointer)close_file_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_CLOSE, 'W', GDK_CONTROL_MASK, 0 },
+   { GNOME_APP_UI_ITEM, _("C_lose All"), _("Close all open files"),(gpointer)close_all_files_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_CLOSE_ALL, 'W',(GdkModifierType)(GDK_CONTROL_MASK | GDK_SHIFT_MASK), 0 },
    GNOMEUIINFO_SEPARATOR,
-   { GNOME_APP_UI_ITEM, _("_Print"), _("Print the current file."),(gpointer)glimmer_print_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_PRINT, 'P', GDK_CONTROL_MASK, 0 },
-   { GNOME_APP_UI_ITEM, _("Print Preview"), _("Preview printing of the current file."),(gpointer)glimmer_print_preview_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_PRINT, 'P',(GdkModifierType)(GDK_CONTROL_MASK | GDK_SHIFT_MASK), 0 },
+   { GNOME_APP_UI_ITEM, _("_Print"), _("Print the current file."),(gpointer)glimmer_print_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_PRINT, 'P', GDK_CONTROL_MASK, 0 },
+   { GNOME_APP_UI_ITEM, _("Print Preview"), _("Preview printing of the current file."),(gpointer)glimmer_print_preview_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_PRINT, 'P',(GdkModifierType)(GDK_CONTROL_MASK | GDK_SHIFT_MASK), 0 },
    GNOMEUIINFO_SEPARATOR,
    GNOMEUIINFO_SUBTREE(_("Sess_ion"), session_menu),
    GNOMEUIINFO_SUBTREE(_("Recent Files"),(gpointer)recent_menu),
    GNOMEUIINFO_SEPARATOR,
-   { GNOME_APP_UI_ITEM, _("_Exit"), _("Exit the program."),(gpointer)pre_exit, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_EXIT, 'Q', GDK_CONTROL_MASK, 0 },
+   GNOMEUIINFO_MENU_EXIT_ITEM((gpointer)pre_exit, 0),
    GNOMEUIINFO_END
 };
 
@@ -132,35 +210,36 @@ GnomeUIInfo edit_menu[] = {
    GNOMEUIINFO_MENU_COPY_ITEM((gpointer)copy_text_cb, 0),
    GNOMEUIINFO_MENU_PASTE_ITEM((gpointer)paste_text_cb, 0),
    GNOMEUIINFO_SEPARATOR,
-   { GNOME_APP_UI_ITEM, _("_Bookmark Line"), _("Reverse Bookmark"),(gpointer)reverse_bookmark_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_ADD, 'B', GDK_CONTROL_MASK, 0 },
+   { GNOME_APP_UI_ITEM, _("_Bookmark Line"), _("Reverse Bookmark"),(gpointer)reverse_bookmark_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_BOOKMARK, 'B', GDK_CONTROL_MASK, 0 },
    GNOMEUIINFO_SEPARATOR,
-   { GNOME_APP_UI_ITEM, _("Clear"), _("Clear selection"),(gpointer)clear_text_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_CLEAR, GDK_F8,(GdkModifierType) 0, 0 },
-   { GNOME_APP_UI_ITEM, _("Clear Line"), _("Clear the current line"),(gpointer)clear_line_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_CLEAR, GDK_F8, GDK_CONTROL_MASK, 0 },
-   { GNOME_APP_UI_ITEM, _("Clear to Line Start"), _("Clear the current line"),(gpointer)clear_start_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_CLEAR, GDK_Home, GDK_MOD1_MASK, 0 },
-   { GNOME_APP_UI_ITEM, _("Clear to Line End"), _("Clear the current line"),(gpointer)clear_end_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_CLEAR, GDK_End, GDK_MOD1_MASK, 0 },
+   { GNOME_APP_UI_ITEM, _("Clear"), _("Clear selection"),(gpointer)clear_text_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_CLEAR, GDK_F8,(GdkModifierType) 0, 0 },
+   { GNOME_APP_UI_ITEM, _("Clear Line"), _("Clear the current line"),(gpointer)clear_line_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_CLEAR, GDK_F8, GDK_CONTROL_MASK, 0 },
+   { GNOME_APP_UI_ITEM, _("Clear to Line Start"), _("Clear the current line"),(gpointer)clear_start_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_CLEAR, GDK_Home, GDK_MOD1_MASK, 0 },
+   { GNOME_APP_UI_ITEM, _("Clear to Line End"), _("Clear the current line"),(gpointer)clear_end_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_CLEAR, GDK_End, GDK_MOD1_MASK, 0 },
    GNOMEUIINFO_SEPARATOR,
-   { GNOME_APP_UI_ITEM, _("Select _All"), _("Select the entire document"),(gpointer)select_all_text_cb, 0, 0, GNOME_APP_PIXMAP_DATA, select_all_xpm, 'A', GDK_MOD1_MASK, 0 },
-   { GNOME_APP_UI_ITEM, _("Select _Line"), _("Select the current line."),(gpointer)select_line_cb, 0, 0, GNOME_APP_PIXMAP_NONE, NULL, 'L', GDK_MOD1_MASK, 0 },
-   { GNOME_APP_UI_ITEM, _("_Select Current"), _("Select the current word"),(gpointer)select_current_cb, 0, 0, GNOME_APP_PIXMAP_DATA, selection_xpm, 'C', GDK_MOD1_MASK, 0 },
+   { GNOME_APP_UI_ITEM, _("Select _All"), _("Select the entire document"),(gpointer)select_all_text_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_SELECT_ALL, 'A', GDK_MOD1_MASK, 0 },
+   { GNOME_APP_UI_ITEM, _("Select _Line"), _("Select the current line."),(gpointer)select_line_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_SELECT_LINE, 'L', GDK_MOD1_MASK, 0 },
+   { GNOME_APP_UI_ITEM, _("_Select Current"), _("Select the current word"),(gpointer)select_current_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_SELECTION, 'C', GDK_MOD1_MASK, 0 },
    GNOMEUIINFO_SEPARATOR,
-   { GNOME_APP_UI_ITEM, _("Re-Highlight"), _("Re-Highlight the current file"),(gpointer)highlight_syntax_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_JUMP_TO, GDK_F4,(GdkModifierType) 0, 0 },
-   { GNOME_APP_UI_ITEM, _("Regenerate Highlight Tables"), _("Regenerate highlighting tables for the current mime-type"),(gpointer)reparse_highlight_table_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_REFRESH, GDK_F4, GDK_CONTROL_MASK, 0 },
+   { GNOME_APP_UI_ITEM, _("Re-Highlight"), _("Re-Highlight the current file"),(gpointer)highlight_syntax_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_REHIGHLIGHT, GDK_F4,(GdkModifierType) 0, 0 },
+   { GNOME_APP_UI_ITEM, _("Regenerate Highlight Tables"), _("Regenerate highlighting tables for the current mime-type"),(gpointer)reparse_highlight_table_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_REGENERATE, GDK_F4, GDK_CONTROL_MASK, 0 },
    GNOMEUIINFO_SEPARATOR,
-   { GNOME_APP_UI_ITEM, _("P_roperties"), _("Edit properties"),(gpointer)edit_properties, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_PROPERTIES, GDK_F2,(GdkModifierType) 0, 0 },
+   { GNOME_APP_UI_ITEM, _("P_roperties"), _("Edit properties"),(gpointer)edit_properties, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_PROPS, GDK_F2,(GdkModifierType) 0, 0 },
    GNOMEUIINFO_END
 };
 
 GnomeUIInfo search_menu[] = {
    GNOMEUIINFO_MENU_FIND_ITEM((gpointer)find_cb, 0),
    GNOMEUIINFO_MENU_REPLACE_ITEM((gpointer)replace_cb, 0),
-   { GNOME_APP_UI_ITEM, _("Goto Line..."), _("Goto a line"),(gpointer)gotoline_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_JUMP_TO, 'L', GDK_CONTROL_MASK, 0 },
-   { GNOME_APP_UI_ITEM, _("Search Manpages(Local)"), _("Search manpages"),(gpointer)manpage_cb, GINT_TO_POINTER(0), 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_INDEX, GDK_F1, GDK_SHIFT_MASK, 0 },
-   { GNOME_APP_UI_ITEM, _("Search Manpages(Gnome)"), _("Search manpages with gnome-help-browser"),(gpointer)manpage_cb, GINT_TO_POINTER(1), 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_INDEX, GDK_F1,(GdkModifierType) 0, 0 },
+   { GNOME_APP_UI_ITEM, _("Goto Line..."), _("Goto a line"),(gpointer)gotoline_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_GOTO_LINE, 'L', GDK_CONTROL_MASK, 0 },
+   { GNOME_APP_UI_ITEM, _("Search Manpages(Local)"), _("Search manpages"),(gpointer)manpage_cb, GINT_TO_POINTER(0), 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_SEARCH, GDK_F1, GDK_SHIFT_MASK, 0 },
+   { GNOME_APP_UI_ITEM, _("Search Manpages(Gnome)"), _("Search manpages with gnome-help-browser"),(gpointer)manpage_cb, GINT_TO_POINTER(1), 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_SEARCH, GDK_F1,(GdkModifierType) 0, 0 },
    GNOMEUIINFO_SEPARATOR,
-   { GNOME_APP_UI_ITEM, _("_Previous Bookmark"), _("Goto the next bookmark"),(gpointer)last_bookmark_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_UP, 'B',(GdkModifierType)(GDK_CONTROL_MASK | GDK_MOD1_MASK), 0 },
-   { GNOME_APP_UI_ITEM, _("_Next Bookmark"), _("Goto the next bookmark"),(gpointer)next_bookmark_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_DOWN, 'B',(GdkModifierType)(GDK_CONTROL_MASK | GDK_SHIFT_MASK), 0 },
+   { GNOME_APP_UI_ITEM, _("_Previous Bookmark"), _("Goto the next bookmark"),(gpointer)last_bookmark_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_PREV_BOOKMARK, 'B',(GdkModifierType)(GDK_CONTROL_MASK | GDK_MOD1_MASK), 0 },
+   { GNOME_APP_UI_ITEM, _("_Next Bookmark"), _("Goto the next bookmark"),(gpointer)next_bookmark_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_NEXT_BOOKMARK, 'B',(GdkModifierType)(GDK_CONTROL_MASK | GDK_SHIFT_MASK), 0 },
    GNOMEUIINFO_SEPARATOR,
-   { GNOME_APP_UI_ITEM, _("Match Bracket"), _("Goto the matching bracket"),(gpointer)match_bracket_cb, 0, 0, GNOME_APP_PIXMAP_NONE, NULL, 'E', GDK_CONTROL_MASK, 0 },
+   { GNOME_APP_UI_ITEM, _("Match Bracket"), _("Goto the matching bracket"),(gpointer)match_bracket_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_BRACKET_MATCH, 'E', GDK_CONTROL_MASK, 0 },
+   { GNOME_APP_UI_ITEM, _("Select To Bracket"), _("Select to the matching bracket"),(gpointer)select_to_bracket_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_BRACKET_MATCH, 'E', (GdkModifierType)(GDK_CONTROL_MASK | GDK_MOD1_MASK), 0 },
    GNOMEUIINFO_END
 };
 
@@ -170,9 +249,12 @@ GnomeUIInfo common_text_menu[] = {
    GNOMEUIINFO_ITEM_NONE(_("_User Name"), _("Insert the name of the current user"),(gpointer)insert_username),         
    GNOMEUIINFO_ITEM_NONE(_("_Name"), _("Insert name(from prefs)"),(gpointer)insert_name),
    GNOMEUIINFO_ITEM_NONE(_("Email _Address"), _("Insert email(from prefs)"),(gpointer)insert_email),         
-   GNOMEUIINFO_ITEM_NONE(_("_GPL Notice(C)"), _("Insert GPL notice with C comments"),(gpointer)insert_gpl_notice),
-   GNOMEUIINFO_ITEM_NONE(_("G_PL Notice(C++)"), _("Insert GPL notice with C++ comments"),(gpointer)insert_gpl_noticepp),
-   GNOMEUIINFO_ITEM_NONE(_("G_PL Notice(#)"), _("Insert GPL notice with # comments"),(gpointer)insert_gpl_noticepython),
+   GNOMEUIINFO_ITEM_NONE(_("GPL Notice(C)"), _("Insert GPL notice with C comments"),(gpointer)insert_gpl_notice),
+   GNOMEUIINFO_ITEM_NONE(_("GPL Notice(C++)"), _("Insert GPL notice with C++ comments"),(gpointer)insert_gpl_noticepp),
+   GNOMEUIINFO_ITEM_NONE(_("GPL Notice(#)"), _("Insert GPL notice with # comments"),(gpointer)insert_gpl_noticepython),
+   GNOMEUIINFO_ITEM_NONE(_("LGPL Notice(C)"), _("Insert LGPL notice with C comments"),(gpointer)insert_lgpl_notice),
+   GNOMEUIINFO_ITEM_NONE(_("LGPL Notice(C++)"), _("Insert LGPL notice with C++ comments"),(gpointer)insert_lgpl_noticepp),
+   GNOMEUIINFO_ITEM_NONE(_("LGPL Notice(#)"), _("Insert LGPL notice with # comments"),(gpointer)insert_lgpl_noticepython),
    GNOMEUIINFO_END
 };
 
@@ -188,11 +270,11 @@ GnomeUIInfo insert_menu[] = {
 };
 
 GnomeUIInfo build_menu[] = {
-   { GNOME_APP_UI_ITEM, _("_Compile"), _("Compile the current source file"),(gpointer)compile_file_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_CONVERT, GDK_F5,(GdkModifierType) 0, 0 },
+   { GNOME_APP_UI_ITEM, _("_Compile"), _("Compile the current source file"),(gpointer)compile_file_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_COMPILE, GDK_F5,(GdkModifierType) 0, 0 },
    { GNOME_APP_UI_ITEM, _("Stop Compile"), _("Kill the currently executing compile process"),(gpointer)kill_compile_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_STOP, 0,(GdkModifierType) 0, 0 },
-   { GNOME_APP_UI_ITEM, _("_Debug"), _("Debug the current source file"),(gpointer)debug_file_cb, 0, 0, GNOME_APP_PIXMAP_DATA, debug_xpm, GDK_F5, GDK_CONTROL_MASK, 0 },
+   { GNOME_APP_UI_ITEM, _("_Debug"), _("Debug the current source file"),(gpointer)debug_file_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_DEBUG, GDK_F5, GDK_CONTROL_MASK, 0 },
    { GNOME_APP_UI_ITEM, _("Stop Debug"), _("Kill the currently executing debug process"),(gpointer)kill_debug_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_STOP, 0,(GdkModifierType) 0, 0 },
-   { GNOME_APP_UI_ITEM, _("_Execute"), _("Execute the current program"),(gpointer)execute_file_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_EXEC, GDK_F5, GDK_SHIFT_MASK, 0 },
+   { GNOME_APP_UI_ITEM, _("_Execute"), _("Execute the current program"),(gpointer)execute_file_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_EXECUTE, GDK_F5, GDK_SHIFT_MASK, 0 },
    { GNOME_APP_UI_ITEM, _("Stop Execution"), _("Kill the currently executing process"),(gpointer)kill_execute_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_STOP, 0,(GdkModifierType) 0, 0 },
    GNOMEUIINFO_END
 };
@@ -204,7 +286,7 @@ GnomeUIInfo docs_menu[] = {
 
 #ifdef WITH_PYTHON
 GnomeUIInfo scripts_menu[] = {
-   { GNOME_APP_UI_ITEM, _("_Regenerate Menu"), _("Regenerate the scripts menu"),(gpointer)regenerate_scripts_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_REFRESH, 0,(GdkModifierType) 0, 0 },
+   { GNOME_APP_UI_ITEM, _("_Regenerate Menu"), _("Regenerate the scripts menu"),(gpointer)regenerate_scripts_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_REGENERATE, 0,(GdkModifierType) 0, 0 },
    GNOMEUIINFO_SEPARATOR,
    GNOMEUIINFO_END
 };
@@ -223,24 +305,32 @@ GnomeUIInfo view_menu[] = {
 #endif
    { GNOME_APP_UI_TOGGLEITEM, _("Status Bar"), _("Toggle the visibility of the Status Bar"),(gpointer)set_statusbar_visibility, NULL, NULL, GNOME_APP_PIXMAP_NONE, NULL, 0,(GdkModifierType) 0, NULL },
    GNOMEUIINFO_SEPARATOR,
-   { GNOME_APP_UI_ITEM, _("Save View Settings"), _("Save the current view settings"),(gpointer)save_view_settings_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_SAVE, 0,(GdkModifierType) 0, 0 },
+   { GNOME_APP_UI_ITEM, _("Save View Settings"), _("Save the current view settings"),(gpointer)save_view_settings_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_SAVE, 0,(GdkModifierType) 0, 0 },
    GNOMEUIINFO_END
 };
 
 GnomeUIInfo settings_menu[] = {
-   { GNOME_APP_UI_ITEM, _("Preferences..."), _("Edit the program preferences"),(gpointer)edit_preferences, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_PREFERENCES, 0,(GdkModifierType) 0, 0 },
-   { GNOME_APP_UI_ITEM, _("Highlight Colors..."), _("Edit the highlighting colors"),(gpointer)change_colors_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_COLORSELECTOR, 0,(GdkModifierType) 0, 0 },
+   { GNOME_APP_UI_ITEM, _("Preferences..."), _("Edit the program preferences"),(gpointer)edit_preferences, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_PREFS, 0,(GdkModifierType) 0, 0 },
+   { GNOME_APP_UI_ITEM, _("Highlight Colors..."), _("Edit the highlighting colors"),(gpointer)change_colors_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_COLORS, 0,(GdkModifierType) 0, 0 },
    GNOMEUIINFO_END
 };
 
 GnomeUIInfo window_menu[] = {
    { GNOME_APP_UI_ITEM, _("New Main _Window"), _("New instance of " PACKAGE),(gpointer)new_window_cb, 0, 0, GNOME_APP_PIXMAP_DATA, window_xpm, 0,(GdkModifierType) 0, 0 },
    GNOMEUIINFO_SEPARATOR,
-   { GNOME_APP_UI_ITEM, _("_Previous File"), _("Goto the previous file in the list."),(gpointer)cycle_left_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_BACK, ',',(GdkModifierType) GDK_CONTROL_MASK, 0 },
-   { GNOME_APP_UI_ITEM, _("_Next File"), _("Goto the next file in the list."),(gpointer)cycle_right_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_FORWARD, '.',(GdkModifierType) GDK_CONTROL_MASK, 0 },
+   { GNOME_APP_UI_ITEM, _("_Previous File"), _("Goto the previous file in the list."),(gpointer)cycle_left_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_PREV_FILE, ',',(GdkModifierType) GDK_CONTROL_MASK, 0 },
+   { GNOME_APP_UI_ITEM, _("_Next File"), _("Goto the next file in the list."),(gpointer)cycle_right_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_NEXT_FILE, '.',(GdkModifierType) GDK_CONTROL_MASK, 0 },
    GNOMEUIINFO_SEPARATOR,
-   { GNOME_APP_UI_ITEM, _("Move File _Backward"), _("Move this file backward in the list."),(gpointer)move_left_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_BACK, ',',(GdkModifierType) GDK_MOD1_MASK, 0 },
-   { GNOME_APP_UI_ITEM, _("Move File _Forward"), _("Move this file forward in the list."),(gpointer)move_right_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_FORWARD, '.',(GdkModifierType) GDK_MOD1_MASK, 0 },
+   { GNOME_APP_UI_ITEM, _("Move File _Backward"), _("Move this file backward in the list."),(gpointer)move_left_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_PREV_FILE, ',',(GdkModifierType) GDK_MOD1_MASK, 0 },
+   { GNOME_APP_UI_ITEM, _("Move File _Forward"), _("Move this file forward in the list."),(gpointer)move_right_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_NEXT_FILE, '.',(GdkModifierType) GDK_MOD1_MASK, 0 },
+#ifdef WITH_PYTHON
+   GNOMEUIINFO_SEPARATOR,
+   { GNOME_APP_UI_ITEM, _("Previous Dock Item"), _("Go to the previous item in the list."),(gpointer)cycle_left_paned_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_NEXT_FILE, ',',(GdkModifierType) (GDK_CONTROL_MASK | GDK_MOD1_MASK), 0 },
+   { GNOME_APP_UI_ITEM, _("Next Dock Item"), _("Go to the next item in the list."),(gpointer)cycle_right_paned_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_NEXT_FILE, '.',(GdkModifierType) (GDK_CONTROL_MASK | GDK_MOD1_MASK), 0 },
+   GNOMEUIINFO_SEPARATOR,
+   { GNOME_APP_UI_ITEM, _("Focus Dock Item"), _("Focus the current dock item."),(gpointer)focus_current_paned_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_NEXT_FILE, '.',(GdkModifierType) (GDK_CONTROL_MASK | GDK_SHIFT_MASK), 0 },
+#endif
+   { GNOME_APP_UI_ITEM, _("Focus Current File"), _("Focus the current file."),(gpointer)focus_current_file_cb, 0, 0, GNOME_APP_PIXMAP_STOCK, GLIMMER_STOCK_PIXMAP_NEXT_FILE, ',',(GdkModifierType) (GDK_CONTROL_MASK | GDK_SHIFT_MASK), 0 },
    GNOMEUIINFO_END
 };
 
@@ -320,6 +410,42 @@ void make_menus(void)
 {
    GtkItemFactory *item_factory;
    gint nmenu_items;
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_NEW, new_menu_xpm, 16);
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_OPEN, open_menu_xpm, 16);
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_REVERT, revert_menu_xpm, 16);
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_CLOSE, close_menu_xpm, 16);
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_CLOSE_ALL, close_all_xpm, 16);
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_SAVE, save_menu_xpm, 16);
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_SAVE_AS, saveas_menu_xpm, 16);
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_SAVE_ALL, save_all_xpm, 16);
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_PRINT, print_menu_xpm, 16);
+
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_BOOKMARK, bookmark_menu_xpm, 16);
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_CLEAR, clear_menu_xpm, 16);
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_SELECTION, selection_xpm, 16);
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_SELECT_LINE, select_line_xpm, 16);
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_SELECT_ALL, select_all_xpm, 16);
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_REHIGHLIGHT, rehighlight_xpm, 16);
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_REGENERATE, regenerate_xpm, 16);
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_PROPS, props_menu_xpm, 16);
+
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_GOTO_LINE, goto_line_xpm, 16);
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_SEARCH, search_menu_xpm, 16);
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_PREV_BOOKMARK, prev_bookmark_xpm, 16);
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_NEXT_BOOKMARK, next_bookmark_xpm, 16);
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_BRACKET_MATCH, bracket_match_xpm, 16);
+
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_COMPILE, compile_menu_xpm, 16);
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_DEBUG, debug_menu_xpm, 16);
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_EXECUTE, execute_menu_xpm, 16);
+
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_PREFS, prefs_menu_xpm, 16);
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_COLORS, colors_menu_xpm, 16);
+
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_WINDOW, window_xpm, 16);
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_PREV_FILE, prev_file_xpm, 16);
+   build_stock_pixmap(GLIMMER_STOCK_PIXMAP_NEXT_FILE, next_file_xpm, 16);
+
    gnome_app_create_menus(GNOME_APP(window), menubar);
    gnome_app_install_appbar_menu_hints(GNOME_APPBAR(appbar), menubar);
 
@@ -354,7 +480,8 @@ void make_menus(void)
    edit_menu_undo = edit_menu[0].widget;   
    edit_menu_redo = edit_menu[1].widget;   
 
-   search_menu_match = search_menu[5].widget;
+   search_menu_match = search_menu[9].widget;
+   search_menu_select = search_menu[10].widget;
 
    build_menu_compile = build_menu[0].widget;
    build_menu_kill_compile = build_menu[1].widget;
@@ -382,6 +509,15 @@ void make_menus(void)
    windows_menu_moveprev = window_menu[5].widget;
    windows_menu_movenext = window_menu[6].widget;
 
+#ifdef WITH_PYTHON
+   windows_paned_left = window_menu[8].widget;
+   windows_paned_right = window_menu[9].widget;
+   windows_focus_paned = window_menu[11].widget;
+   windows_focus_file = window_menu[12].widget;
+#else
+   windows_focus_file = window_menu[8].widget;
+#endif
+
    nmenu_items = sizeof(popup_items) / sizeof(popup_items[0]);
    item_factory = gtk_item_factory_new(GTK_TYPE_MENU, "<edit popup>", 0);
    gtk_item_factory_create_items(item_factory, nmenu_items, popup_items, 0);
