@@ -7,7 +7,7 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
@@ -60,6 +60,7 @@ extern GtkWidget *file_menu_print_preview;
 extern GtkWidget *edit_menu_undo;
 extern GtkWidget *edit_menu_redo;
 extern GtkWidget *search_menu_match;
+extern GtkWidget *search_menu_select;
 extern GtkWidget *build_menu_compile;
 extern GtkWidget *build_menu_kill_compile;
 extern GtkWidget *build_menu_debug;
@@ -81,6 +82,12 @@ extern GtkWidget *windows_menu_prev;
 extern GtkWidget *windows_menu_next;
 extern GtkWidget *windows_menu_moveprev;
 extern GtkWidget *windows_menu_movenext;
+#ifdef WITH_PYTHON
+extern GtkWidget *windows_paned_left;
+extern GtkWidget *windows_paned_right;
+extern GtkWidget *windows_focus_paned;
+#endif
+extern GtkWidget *windows_focus_file;
 extern GtkWidget *edit_popup_menu;
 
 #ifdef __cplusplus
