@@ -7,7 +7,7 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
@@ -28,9 +28,9 @@ gchar *replace_percent_tokens(const gchar *string)
    gchar *file;
    gchar *new_string = NULL;
    gchar *ptr;
-   path = get_path_from_filename(cur_file->filename);
-   filename = get_file_from_filename(cur_file->filename);
-   file = get_file_wo_extension(cur_file->filename);
+   path = gds_file_get_path(cur_file);
+   filename = gds_file_get_filename(cur_file);
+   file = gds_file_get_filename_nix_extension(cur_file);
    new_string = g_strdup(string);
    while(1)
    {
@@ -62,6 +62,7 @@ gchar *replace_percent_tokens(const gchar *string)
       if(ptr) { g_free(new_string); new_string = ptr; }
       else { break; }
    }
+   //FIXME: should we release the strings in this routine?
    return(new_string);
 }
 
@@ -86,7 +87,8 @@ gchar *get_file_from_filename(gchar *filename)
 {
    gchar *text = NULL;
    text =  strrchr(filename, '/');
-   if(text) { text++; } else { text = filename; }
+   if(text) text++;
+   else text = filename;
    return(g_strdup(text));
 }
 
@@ -360,3 +362,119 @@ GList *build_file_list(void)
    temp = g_list_copy(files_list);
    return(temp);
 }
+
+gchar *localize_uri_string(gchar *string)
+{
+   gchar find[] = "file://";
+   gchar *temp;
+   temp = strstr(string, find);
+   if(temp) temp += strlen(find);
+   else temp = string;
+   return(g_strdup(temp));
+}
+
+void build_stock_pixmap(gchar *label, gchar **xpm_data, gint size)
+{
+   GnomePixmap *pixmap;
+   GnomeStockPixmapEntry *entry;
+   gint state;
+
+   for(state = 0; state < 3; state++)
+   {
+      pixmap = (GnomePixmap *)gnome_pixmap_new_from_xpm_d_at_size (xpm_data, size, size);
+      entry = g_malloc0(sizeof(GnomeStockPixmapEntry));
+      entry->type = GNOME_STOCK_PIXMAP_TYPE_GPIXMAP;
+      entry->gpixmap.width = size;
+      entry->gpixmap.height = size;
+      entry->gpixmap.label = g_strdup(label);
+      entry->gpixmap.pixmap = pixmap;
+      switch(state)
+      {
+         case 0:
+            gnome_stock_pixmap_register(label, GNOME_STOCK_PIXMAP_REGULAR, entry);
+            break;
+         case 1:
+            gnome_stock_pixmap_register(label, GNOME_STOCK_PIXMAP_FOCUSED, entry);
+            break;
+         case 2:
+            modify_pixmap_state(window, GTK_STATE_INSENSITIVE, &pixmap);
+            gnome_stock_pixmap_register(label, GNOME_STOCK_PIXMAP_DISABLED, entry);
+            break;
+      }
+   }
+}
+
+void modify_pixmap_state(GtkWidget *window, GtkStateType state, GnomePixmap **inout_pixmap)
+{
+	GdkGC *gc;
+	GdkWindow *pixmap = (*inout_pixmap)->pixmap;
+	gint w, h, x, y;
+	GdkGCValues vals;
+	GdkVisual *visual;
+	GdkImage *image;
+	GdkColorContext *cc;
+	GdkColormap *cmap;
+	gint32 red, green, blue;
+	GtkStyle *style;
+	int use_stripple = -1;
+
+	g_return_if_fail(window != NULL);
+
+	/* values for use_stripple:
+	 * 0 - decide upon the value of cc->mode
+	 * 1 - always stripple
+	 * 2 - always shade */
+	use_stripple = gnome_config_get_int("/Gnome/Icons/Shade=0");
+
+	gdk_window_get_size(pixmap, &w, &h);
+	visual = gtk_widget_get_visual(GTK_WIDGET(*inout_pixmap));
+	cmap = gtk_widget_get_colormap(GTK_WIDGET(*inout_pixmap));
+	gc = gdk_gc_new (pixmap);
+
+	cc = gdk_color_context_new(visual, cmap);
+	if (((cc->mode != GDK_CC_MODE_TRUE) &&
+	     (cc->mode != GDK_CC_MODE_MY_GRAY) &&
+	     (use_stripple != 2)) || 
+	    (use_stripple == 1)) {
+		gdk_color_context_free(cc);
+		style = gtk_widget_get_style(window);
+		gdk_gc_set_foreground (gc, &style->bg[state]);
+		for (y = 0; y < h; y ++) {
+			for (x = y % 2; x < w; x += 2) {
+				gdk_draw_point(pixmap, gc, x, y);
+			}
+		}
+		gdk_gc_destroy(gc);
+		return;
+	}
+
+	image = gdk_image_get(pixmap, 0, 0, w, h);
+	gdk_gc_get_values(gc, &vals);
+	style = gtk_widget_get_style(window);
+	red = style->bg[state].red;
+	green = style->bg[state].green;
+	blue = style->bg[state].blue;
+	for (y = 0; y < h; y++) {
+		for (x = 0; x < w; x++) {
+			GdkColor c;
+			int failed;
+			c.pixel = gdk_image_get_pixel(image, x, y);
+			gdk_color_context_query_color(cc, &c);
+			c.red = (((gint32)c.red - red) >> 1)
+				+ red;
+			c.green = (((gint32)c.green - green) >> 1)
+				+ green;
+			c.blue = (((gint32)c.blue - blue) >> 1)
+				+ blue;
+			c.pixel = gdk_color_context_get_pixel(cc, c.red,
+							      c.green,
+							      c.blue,
+							      &failed);
+			gdk_image_put_pixel(image, x, y, c.pixel);
+		}
+	}
+	gdk_draw_image(pixmap, gc, image, 0, 0, 0, 0, w, h);
+	gdk_image_destroy(image);
+	gdk_gc_destroy(gc);
+	gdk_color_context_free(cc);
+}
