@@ -7,7 +7,7 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
@@ -65,7 +65,7 @@ void edit_properties(GtkWidget *widget, gpointer data)
 
    props_window = gtk_window_new(GTK_WINDOW_DIALOG);
    gtk_container_set_border_width(GTK_CONTAINER(props_window), 5);
-   chars = g_strconcat(_("GdsFileProperties Editor - "), cur_file->filename, NULL);
+   chars = g_strconcat(_("Properties Editor - "), cur_file->filename, NULL);
    gtk_window_set_title(GTK_WINDOW(props_window), chars);
    g_free(chars);
    cur_file->props_dialog = props_window;
@@ -245,18 +245,18 @@ void save_properties(GtkWidget *widget, FileProps *props)
 static void set_properties(GtkWidget *widget, GdsFile *temp)
 {
    gboolean highlight;
-   highlight = GDS_EDITOR(temp->text)->highlight;
+   highlight = GTK_EXTEXT(temp->text)->highlight;
    if(temp->props.over_ride)
    {
       if(highlight != temp->props.syntax)
-         gds_editor_set_highlight(GDS_EDITOR(temp->text), temp->props.syntax);
+         gtk_extext_set_highlight(GTK_EXTEXT(temp->text), temp->props.syntax);
       GTK_EXTEXT(temp->text)->default_tab_width = temp->props.spaces;
       gtk_widget_queue_draw(temp->text);
    }
    else
    {
       if(highlight != general_preferences.syntax)
-         gds_editor_set_highlight(GDS_EDITOR(temp->text), general_preferences.syntax);
+         gtk_extext_set_highlight(GTK_EXTEXT(temp->text), general_preferences.syntax);
       GTK_EXTEXT(temp->text)->default_tab_width = general_preferences.spaces;
       gtk_widget_queue_draw(temp->text);
    }
