@@ -7,7 +7,7 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
@@ -25,19 +25,59 @@ extern "C" {
 
 struct preferences
 {
+   // General/UI
+   gboolean full_filenames_title;
+   gboolean full_filenames;
+   gboolean async_xfer;
+   gboolean close_all;
+   gboolean untitled;
+   gboolean show_dots;
+   gboolean show_details;
+   gboolean draw_numbers;
+   gboolean draw_pixmaps;
+   gboolean cursor_blink;
+   gboolean full_selection;
+   // Style For Toolbars
+   gint toolbar_style;
+   // Notebook Tab Position
+   gint notebook_tab_position;
+   // Directory Settings
    gchar default_dir[256];
    gchar projects_dir[256];
    gchar terminal[256];
    gchar make[256];
+   // History Settings
    gboolean save_toolbars;
    gboolean save_session;
    gboolean open_session;
    gboolean auto_save;
    gint history;
    gint undo_max;
+   // User settings
    gchar name[256];
    gchar email[256];
-   gint notebook_tab_position;
+   // File Settings
+   gboolean bracketmatch;
+   gboolean select_line;
+   gboolean syntax;
+   gboolean auto_indent;
+   gboolean use_spaces;
+   gboolean tab_stops;
+   guint spaces;
+   // Window Settings
+   gint geometry;
+   gint x;
+   gint y;
+   gint w;
+   gint h;
+   gchar print_font[128];
+   gint print_landscape;
+   gboolean print_header;
+   gboolean print_numbers;
+   gint print_every_n_lines;
+   gboolean print_with_wrap;
+
+   // Style settings
    gboolean use_gtk_theme;
    gchar font_name[256];
    GdkFont *font;
@@ -52,34 +92,10 @@ struct preferences
    GdkColor s_bg;
    GdkColor bm_bg;
    GdkColor gutter_bg;
+   GdkColor nb_normal;
+   GdkColor nb_changed;
    GnomePixmap *bg_pixmap;
    gchar pixmap_name[256];
-   gboolean full_filenames_title;
-   gboolean full_filenames;
-   gboolean close_all;
-   gboolean untitled;
-   gboolean full_selection;
-   gboolean draw_numbers;
-   gboolean draw_pixmaps;
-   gboolean cursor_blink;
-   gboolean bracketmatch;
-   gboolean select_line;
-   gboolean syntax;
-   gboolean auto_indent;
-   gboolean use_spaces;
-   gboolean tab_stops;
-   guint spaces;
-   gint geometry;
-   gint x;
-   gint y;
-   gint w;
-   gint h;
-   gchar print_font[128];
-   gint print_landscape;
-   gboolean print_header;
-   gboolean print_numbers;
-   gint print_every_n_lines;
-   gboolean print_with_wrap;
 };
 
 typedef struct preferences Preferences;
