@@ -7,7 +7,7 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
@@ -15,6 +15,7 @@
  */
 
 #include "declarations.h"
+#include "bindings.h"
 #include "signals.h"
 
 #ifdef WITH_PYTHON
@@ -58,7 +59,6 @@ gboolean file_emit_scripting_signal(gchar *signal, GdsFile *file)
       result = call_scripting_function(file->tables->tab_pressed_callback);
    else if(!strcmp(signal, "anti-tab-pressed") && file->tables->anti_tab_pressed_callback)
       result = call_scripting_function(file->tables->anti_tab_pressed_callback);
-
    else if(!strcmp(signal, "compile") && file->tables->compile_hook)
       result = call_scripting_function(file->tables->compile_hook);
    else if(!strcmp(signal, "stop-compile") && file->tables->stop_compile_hook)
@@ -127,6 +127,17 @@ gboolean check_scripting_function(gpointer function)
    return(TRUE);
 }
 
+gboolean call_scripting_function_extended(gpointer function, gint control, gint shift, gint alt, gint key, gint pos)
+{
+   PyObject* result;
+   if(!PyCallable_Check((PyObject*)function))
+      return(FALSE);
+   g_print("calling extended function...\n");
+   result = PyObject_CallFunction((PyObject*)function, "iiiiii", get_file_number(), control, shift, alt, key, pos);
+   Py_XDECREF(result);
+   return(TRUE);
+}
+
 /*
 This is called when killing highlight tables.
 It goes through the hook lists and decref's all entries
