@@ -7,7 +7,7 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
@@ -17,6 +17,7 @@
 #include <libgnomevfs/gnome-vfs-mime.h>
 
 #include "declarations.h"
+#include "gtkextext/gtkextext.h"
 #include "syntax-highlight.h"
 #include "colors.h"
 #include "insert.h"
@@ -191,11 +192,11 @@ void apply_color_changes(void)
    {
       current = (GdsFile *)temp->data;
       if(current->tables && current->tables->syntax)
-         gds_editor_install_table(GDS_EDITOR(current->text), current->tables->syntax);
+         gtk_extext_install_table(GTK_EXTEXT(current->text), current->tables->syntax);
       if(current->tables && current->tables->pattern)
-         gds_editor_install_table(GDS_EDITOR(current->text), current->tables->pattern);
+         gtk_extext_install_table(GTK_EXTEXT(current->text), current->tables->pattern);
       if(current->tables && current->tables->embedded)
-         gds_editor_install_table(GDS_EDITOR(current->text), current->tables->embedded);
+         gtk_extext_install_table(GTK_EXTEXT(current->text), current->tables->embedded);
       if(current == cur_file) gtk_widget_queue_draw(current->text);
    }
 }
@@ -243,7 +244,6 @@ void attach_highlight_tables(GdsFile *file_ptr, gchar *path_to_file)
       if(extension) extension++;
       else extension = filename;
       mime_type = (gchar *) gnome_vfs_mime_type_from_name(filename);
-      g_print("Extension: %s, mime-type: %s.\n", extension, mime_type);
       table = find_highlight_tables(extension, mime_type, home_dir);
       if(!table) table = find_highlight_tables(extension, mime_type, install_dir);
    }
@@ -252,10 +252,10 @@ void attach_highlight_tables(GdsFile *file_ptr, gchar *path_to_file)
    {
       file_ptr->tables = table;
       table->refcount++;
-      if(table->syntax) gds_editor_install_table(GDS_EDITOR(file_ptr->text), table->syntax);
-      if(table->pattern) gds_editor_install_table(GDS_EDITOR(file_ptr->text), table->pattern);
-      if(table->embedded) gds_editor_install_table(GDS_EDITOR(file_ptr->text), table->embedded);
-      gds_editor_set_highlight(GDS_EDITOR(file_ptr->text), general_preferences.syntax);
+      if(table->syntax) gtk_extext_install_table(GTK_EXTEXT(file_ptr->text), table->syntax);
+      if(table->pattern) gtk_extext_install_table(GTK_EXTEXT(file_ptr->text), table->pattern);
+      if(table->embedded) gtk_extext_install_table(GTK_EXTEXT(file_ptr->text), table->embedded);
+      gtk_extext_set_highlight(GTK_EXTEXT(file_ptr->text), general_preferences.syntax);
 #ifdef WITH_PYTHON
       if(table->table_add_callback) table_emit_scripting_signal("table-add", file_ptr->tables);
       if(table->file_focus_callback) file_emit_scripting_signal("focus-in", file_ptr);
@@ -263,7 +263,7 @@ void attach_highlight_tables(GdsFile *file_ptr, gchar *path_to_file)
    }
    else
    {
-      gds_editor_set_highlight(GDS_EDITOR(file_ptr->text), FALSE);
+      gtk_extext_set_highlight(GTK_EXTEXT(file_ptr->text), FALSE);
    }
    g_free(filename);
 }
@@ -282,10 +282,10 @@ gboolean detach_highlight_tables(GdsFile *file_ptr)
       file_ptr->tables->refcount--;
       delete_highlight_tables(file_ptr->tables);
       file_ptr->tables = NULL;
-      GDS_EDITOR(file_ptr->text)->syntax_table = NULL;
-      GDS_EDITOR(file_ptr->text)->pattern_table = NULL;
-      GDS_EDITOR(file_ptr->text)->embedded_table = NULL;      
-      gds_editor_set_highlight(GDS_EDITOR(file_ptr->text), FALSE);      
+      GTK_EXTEXT(file_ptr->text)->syntax_table = NULL;
+      GTK_EXTEXT(file_ptr->text)->pattern_table = NULL;
+      GTK_EXTEXT(file_ptr->text)->embedded_table = NULL;      
+      gtk_extext_set_highlight(GTK_EXTEXT(file_ptr->text), FALSE);      
       return(TRUE);
    }
    else return(FALSE);
@@ -297,9 +297,9 @@ gboolean delete_highlight_tables(GdsFileHighlightTable *table)
    GList *list = NULL;
 #endif
    if(table->refcount > 0) return(FALSE);
-   if(table->syntax) gds_editor_table_free(table->syntax);
-   if(table->pattern) gds_editor_table_free(table->pattern);
-   if(table->embedded) gds_editor_table_free(table->embedded);
+   if(table->syntax) gtk_extext_table_free(table->syntax);
+   if(table->pattern) gtk_extext_table_free(table->pattern);
+   if(table->embedded) gtk_extext_table_free(table->embedded);
    g_free(table->filename);
    g_list_delete_all(table->extensions);
    g_list_delete_all(table->mime_types);
@@ -485,20 +485,26 @@ gboolean check_mime_type(xmlDocPtr doc, gchar *extension, gchar *mime_type)
       if(!strcmp(node->name, "extension"))
       {
          namestring = xmlNodeListGetString(doc, node->xmlChildrenNode, 1);
-         if(!strcmp(namestring, extension))
+         if(namestring)
          {
-            found = TRUE;
+            if(!strcmp(namestring, extension))
+            {
+               found = TRUE;
+            }
+            g_free(namestring);
          }
-         g_free(namestring);
       }
       else if(!strcmp(node->name, "mime-type"))
       {
          namestring = xmlNodeListGetString(doc, node->xmlChildrenNode, 1);
-         if(!strcmp(namestring, mime_type))
+         if(namestring)
          {
-            found = TRUE;
+            if(!strcmp(namestring, mime_type))
+            {
+               found = TRUE;
+            }
+            g_free(namestring);
          }
-         g_free(namestring);
       }
       if(found) break;
    }
@@ -692,7 +698,7 @@ GdsFileHighlightTable *make_highlight_tables(xmlDocPtr doc, gchar *filename)
                   info = get_highlight_info(style, cclass);
                else
                   info = get_highlight_info(style, default_class);
-               syntax_list = gds_editor_syntax_entry_new(syntax_list, name, start, end, info->color, NULL, info->font, info->flags, info->type);
+               syntax_list = gtk_extext_syntax_entry_new(syntax_list, name, start, end, info->color, NULL, info->font, info->flags, GINT_TO_POINTER(info->type));
                g_free(info);
             }
             if(name) { g_free(name); name = NULL; }
@@ -739,7 +745,7 @@ GdsFileHighlightTable *make_highlight_tables(xmlDocPtr doc, gchar *filename)
                   info = get_highlight_info(style, cclass);
                else
                   info = get_highlight_info(style, default_class);
-               pattern_list = gds_editor_pattern_entry_new(pattern_list, name, regex, info->color, NULL, info->font, info->flags, info->type);
+               pattern_list = gtk_extext_pattern_entry_new(pattern_list, name, regex, info->color, NULL, info->font, info->flags, GINT_TO_POINTER(info->type));
                g_free(info);
             }
             if(name) { g_free(name); name = NULL; }
@@ -762,19 +768,13 @@ GdsFileHighlightTable *make_highlight_tables(xmlDocPtr doc, gchar *filename)
                   name = xmlNodeListGetString(doc, item->xmlChildrenNode, 1);
                   found_count++;
                }
-               else if(!strcmp(item->name, "start-regex"))
+               else if(!strcmp(item->name, "outside-regex"))
                {
                   start = xmlNodeListGetString(doc, item->xmlChildrenNode, 1);
                   g_strconvescape(start);
                   found_count++;
                }
-               else if(!strcmp(item->name, "end-regex"))
-               {
-                  end = xmlNodeListGetString(doc, item->xmlChildrenNode, 1);
-                  g_strconvescape(end);
-                  found_count++;
-               }
-               else if(!strcmp(item->name, "regex"))
+               else if(!strcmp(item->name, "inside-regex"))
                {
                   regex = xmlNodeListGetString(doc, item->xmlChildrenNode, 1);
                   g_strconvescape(regex);
@@ -791,18 +791,17 @@ GdsFileHighlightTable *make_highlight_tables(xmlDocPtr doc, gchar *filename)
                   class_found = TRUE;;
                }
             }
-            if(found_count == 5)
+            if(found_count == 4)
             {
                if(class_found)
                   info = get_highlight_info(style, cclass);
                else
                   info = get_highlight_info(style, default_class);
-               embedded_list = gds_editor_embedded_entry_new(embedded_list, name, start, end, regex, info->color, NULL, info->font, info->flags, info->type);
+               embedded_list = gtk_extext_embedded_entry_new(embedded_list, name, start, regex, info->color, NULL, info->font, info->flags, GINT_TO_POINTER(info->type));
                g_free(info);
             }
             if(name) { g_free(name); name = NULL; }
             if(start) { g_free(start); start = NULL; }
-            if(end) { g_free(end); end = NULL; }
             if(regex) { g_free(regex); regex = NULL; }
             if(style) { g_free(style); style = NULL; }
             if(cclass) { g_free(cclass); cclass = NULL; }
@@ -814,9 +813,9 @@ GdsFileHighlightTable *make_highlight_tables(xmlDocPtr doc, gchar *filename)
    run_python_file(filename);
 #endif
 
-   if(syntax_list) new_table->syntax = gds_editor_syntax_table_new(syntax_list);
-   if(pattern_list) new_table->pattern = gds_editor_pattern_table_new(pattern_list);
-   if(embedded_list) new_table->embedded = gds_editor_embedded_table_new(embedded_list);
+   if(syntax_list) new_table->syntax = gtk_extext_syntax_table_new(syntax_list);
+   if(pattern_list) new_table->pattern = gtk_extext_pattern_table_new(pattern_list);
+   if(embedded_list) new_table->embedded = gtk_extext_embedded_table_new(embedded_list);
 
    syntax_list = NULL;
    pattern_list = NULL;
@@ -940,9 +939,9 @@ void highlight_tables_font_change(GdkFont *nfont, gint type)
    GList *tables = NULL;
    GList *entry = NULL;
    GdsFileHighlightTable *table;
-   GdsEditorSyntaxEntry *syntax;
-   GdsEditorPatternEntry *pattern;
-   GdsEditorEmbeddedEntry *embedded;
+   GtkExTextSyntaxEntry *syntax;
+   GtkExTextPatternEntry *pattern;
+   GtkExTextEmbeddedEntry *embedded;
    
    for(tables = g_list_first(highlight_tables); tables; tables = tables->next)
    {
@@ -950,22 +949,22 @@ void highlight_tables_font_change(GdkFont *nfont, gint type)
       if(table->syntax)
       for(entry = g_list_first(table->syntax->entries); entry; entry = entry->next)
       {
-         syntax = (GdsEditorSyntaxEntry *)entry->data;
-         if(syntax->type == type)
+         syntax = (GtkExTextSyntaxEntry *)entry->data;
+         if(GPOINTER_TO_INT(syntax->data) == type)
             syntax->font = nfont;
       }
       if(table->pattern)
       for(entry = g_list_first(table->pattern->entries); entry; entry = entry->next)
       {
-         pattern = (GdsEditorPatternEntry *)entry->data;
-         if(pattern->type == type)
+         pattern = (GtkExTextPatternEntry *)entry->data;
+         if(GPOINTER_TO_INT(pattern->data) == type)
             pattern->font = nfont;
       }
       if(table->embedded)
       for(entry = g_list_first(table->embedded->entries); entry; entry = entry->next)
       {
-         embedded = (GdsEditorEmbeddedEntry *)entry->data;
-         if(embedded->type == type)
+         embedded = (GtkExTextEmbeddedEntry *)entry->data;
+         if(GPOINTER_TO_INT(embedded->data)== type)
             embedded->font = nfont;
       }
    }
