@@ -1,19 +1,24 @@
 /*  Glimmer - gdsfile.c
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
+ *  This library is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU Library General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Library General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
+ *  You should have received a copy of the GNU Library General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include <libgnomevfs/gnome-vfs-types.h>
+#include <libgnomevfs/gnome-vfs-uri.h>
+#include <libgnomevfs/gnome-vfs-mime.h>
+#include <libgnomevfs/gnome-vfs-mime-info.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
 #include <signal.h>
 
 #include <config.h>
@@ -22,17 +27,18 @@
 #include "../main.h"
 #include "../menus.h"
 #include "../signals.h"
+#include "xpm/file-selector-file.xpm"
 
 static void gds_file_init(GdsFile *gds_file);
 static void gds_file_class_init(GdsFileClass *klass);
 static void gds_file_destroy(GtkObject *object);
+static void gds_file_construct_labels(GdsFile *gds_file, gboolean full);
 static gint button_press_cb(GtkWidget *widget, GdkEventButton *event);
 static gint key_press_cb(GtkWidget *widget, GdkEventKey *event, GdsFile *gds_file);
 static gchar *make_spaces_string(gint spaces);
-
 void bracket_match_cb(GtkWidget *widget, gint pos, GdsFile *gds_file);
 
-static GtkVBoxClass *parent_class = NULL;
+static GtkHBoxClass *parent_class = NULL;
 
 static gint global_undomax = 0;
 static gint global_spaces = 0;
@@ -56,7 +62,7 @@ GtkType gds_file_get_type(void)
          NULL,
          (GtkClassInitFunc)NULL,
       };
-      gds_file_type = gtk_type_unique(GTK_TYPE_VBOX, &gds_file_info);
+      gds_file_type = gtk_type_unique(GTK_TYPE_HBOX, &gds_file_info);
    }
    return(gds_file_type);
 }
@@ -71,7 +77,12 @@ static void gds_file_class_init(GdsFileClass *klass)
 
 static void gds_file_init(GdsFile *gds_file)
 {
+   gds_file->uri = NULL;
    gds_file->filename = NULL;
+   gds_file->need_pass = FALSE;
+   gds_file->xfering = FALSE;
+   gds_file->xfer_finish = (GtkSignalFunc) NULL;
+   gds_file->xfer_data = NULL;
    gds_file->tables = NULL;
    gds_file->default_lang = TRUE;
    gds_file->changed_set = FALSE;
@@ -90,24 +101,19 @@ static void gds_file_init(GdsFile *gds_file)
    gds_file->exec_pid = 0;
 }
 
-GtkWidget* gds_file_new(gchar *filename, gboolean full)
+GtkWidget* gds_file_new(GnomeVFSURI *uri, gboolean full)
 {
    GdsFile *gds_file;
    GtkWidget *vbox;
    GtkWidget *hbox;
    GtkWidget *hscroll;
-   gchar *str;
    
    gds_file = gtk_type_new(GDS_TYPE_FILE);
-   gds_file_set_filename(gds_file, filename);
-
-   if(!full && (str = strrchr(filename, '/'))) str++;
-   else str = filename;
-   gds_file->menu_item = gnome_stock_menu_item(GNOME_STOCK_PIXMAP_NEW, str);
-   gtk_widget_show(gds_file->menu_item); 
 
    gds_file->tear_away = gds_tear_away_new(GTK_POS_LEFT);
    gtk_widget_show(gds_file->tear_away);
+
+   gds_file_set_uri(gds_file, uri, full);
    
    gds_file->paned = gtk_vpaned_new();
    gtk_paned_set_gutter_size(GTK_PANED(gds_file->paned), 12);
@@ -152,10 +158,13 @@ static void gds_file_destroy(GtkObject *object)
    gds_file = GDS_FILE(object);
    if(gds_file->props_dialog)
       gtk_widget_destroy(gds_file->props_dialog);
+   gtk_widget_destroy(gds_file->pixmap);
    gtk_widget_destroy(gds_file->menu_item);
+   gtk_widget_destroy(gds_file->nb_label);
    gtk_widget_destroy(gds_file->text);
    gtk_widget_destroy(gds_file->tear_away);
-   g_free(gds_file->filename);
+   if(gds_file->uri) gnome_vfs_uri_unref(gds_file->uri);
+   if(gds_file->filename) g_free(gds_file->filename);
    g_free(gds_file->props.dir);
    g_free(gds_file->props.compiler);
    g_free(gds_file->props.debugger);
@@ -166,41 +175,71 @@ static void gds_file_destroy(GtkObject *object)
 	GTK_OBJECT_CLASS(parent_class)->destroy(object);
 }
 
-void gds_file_set_filename(GdsFile *gds_file, gchar *filename)
+void gds_file_set_uri(GdsFile *gds_file, GnomeVFSURI *uri, gboolean full)
 {
    g_return_if_fail(gds_file != NULL);
    g_return_if_fail(GDS_IS_FILE(gds_file));
-   if(gds_file->filename)
-      g_free(gds_file->filename);
-   gds_file->filename = g_new(char, strlen(filename)+1);
-   strcpy(gds_file->filename, filename);
+   if(gds_file->uri && gds_file->uri != uri)
+   {
+      gnome_vfs_uri_unref(gds_file->uri);
+   }
+   gds_file->uri = uri;
+   gnome_vfs_uri_ref(gds_file->uri);
+   if(gds_file->filename) g_free(gds_file->filename);
+   gds_file->filename = gds_file_display_filename(uri, TRUE);
+   gds_file_construct_labels(gds_file, full);
 }
 
-void gds_file_set_title(GdsFile *gds_file, gchar *title, gboolean full)
+static void gds_file_construct_labels(GdsFile *gds_file, gboolean full)
 {
-   GtkWidget *parent;
-   gchar *str;
-   gint pos = 0;
-   g_return_if_fail(gds_file != NULL);
-   g_return_if_fail(GDS_IS_FILE(gds_file));
-   parent = gds_file->menu_item->parent;
-   if(!full && (str = strrchr(title, '/'))) str++;
-   else str = title;
-   pos = g_list_index(GTK_MENU_SHELL(parent)->children, gds_file->menu_item);
-   gtk_widget_destroy(gds_file->menu_item);   
+   GtkWidget *label;
+   gchar *str = NULL;
+   gchar *pixstr = NULL;
 
-   if(!gds_file->changed_set)
-      gds_file->menu_item = gnome_stock_menu_item(GNOME_STOCK_PIXMAP_NEW, str);
+   str = gds_file_display_filename(gds_file->uri, full);
+   if(gds_file->pixmap) gtk_widget_destroy(gds_file->pixmap);
+   if((pixstr = (gchar *)gnome_vfs_mime_get_value((gchar *)gnome_vfs_mime_type_from_name(str), "icon-filename")))
+   {
+      gds_file->pixmap = gnome_pixmap_new_from_file_at_size(pixstr, 18, 18);
+   }
    else
-      gds_file->menu_item = gnome_stock_menu_item(GNOME_STOCK_PIXMAP_PROPERTIES, str);
-   gtk_menu_shell_insert(GTK_MENU_SHELL(parent), gds_file->menu_item, pos);
-   gtk_widget_show(gds_file->menu_item);
-
-   gtk_notebook_set_tab_label_text(GTK_NOTEBOOK(files_book), gds_file->tear_away, str);
-   gtk_notebook_set_menu_label_text(GTK_NOTEBOOK(files_book), gds_file->tear_away, str);
+   {
+      gds_file->pixmap = gnome_pixmap_new_from_xpm_d(file_selector_file_xpm);
+   }
+   if(!gds_file->menu_item)
+   {
+      gds_file->menu_item = gtk_pixmap_menu_item_new();
+      label = gtk_label_new(str);
+      gtk_container_add(GTK_CONTAINER(gds_file->menu_item), label);
+      gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+      gtk_widget_show(label);
+      gtk_widget_show(gds_file->menu_item);
+      gds_file->nb_label = gtk_label_new(str);
+      gtk_widget_show(gds_file->nb_label);
+   }
+   else
+   {
+      gtk_label_set(GTK_LABEL(GTK_BIN(gds_file->menu_item)->child), str);
+      gtk_label_set(GTK_LABEL(gds_file->nb_label), str);
+   }
    gds_tear_away_set_title(GDS_TEAR_AWAY(gds_file->tear_away), str);
+   gtk_pixmap_menu_item_set_pixmap(GTK_PIXMAP_MENU_ITEM(gds_file->menu_item), gds_file->pixmap);
+   gtk_widget_show(gds_file->pixmap);
+   g_free(str);
 }
 
+void gds_file_set_title(GdsFile *gds_file, gboolean full)
+{
+   gchar *str = NULL;
+
+   g_return_if_fail(gds_file != NULL);
+   g_return_if_fail(GDS_IS_FILE(gds_file));
+   str = gds_file_display_filename(gds_file->uri, full);
+   gtk_label_set(GTK_LABEL(GTK_BIN(gds_file->menu_item)->child), str);
+   gtk_label_set(GTK_LABEL(gds_file->nb_label), str);
+   gds_tear_away_set_title(GDS_TEAR_AWAY(gds_file->tear_away), str);
+   g_free(str);
+}
 
 static gint button_press_cb(GtkWidget *widget, GdkEventButton *event)
 {
@@ -229,13 +268,15 @@ static gint key_press_cb(GtkWidget *widget, GdkEventKey *event, GdsFile *gds_fil
    gchar *chars = NULL, *spaces = NULL;
    gboolean shift_state;
    gboolean control_state;
+   gboolean alt_state;
    gint key;
    gint abscol;
    gint tabstop;
 
-   shift_state = event->state & GDK_SHIFT_MASK;
    control_state = event->state & GDK_CONTROL_MASK;  
-   key=event->keyval;
+   shift_state = event->state & GDK_SHIFT_MASK;
+   alt_state = event->state & GDK_MOD1_MASK;  
+   key = event->keyval;
    
    text = (GtkExText *)widget;
    if(!gtk_extext_get_editable(text)) return(handled);
@@ -245,13 +286,6 @@ static gint key_press_cb(GtkWidget *widget, GdkEventKey *event, GdsFile *gds_fil
    {
       abscol = gtk_extext_get_abs_column(text, curpos);
       tabstop = gtk_extext_get_next_tab_stop(text, curpos);
-#ifdef WITH_PYTHON
-      if(event->keyval == GDK_Tab && control_state && file_emit_scripting_signal("anti-tab-pressed", gds_file))
-      {
-         handled = TRUE;
-      }
-      else
-#endif
       if(text->has_selection && text->selection_start_pos != text->selection_end_pos)
       {
          gint start = 0;
@@ -272,91 +306,107 @@ static gint key_press_cb(GtkWidget *widget, GdkEventKey *event, GdsFile *gds_fil
          current_line = first_line;
          if(first_line == last_line)
          {
-            gtk_extext_freeze(text);
-            gtk_extext_delete_text(text, start, end);
-            text->has_selection = FALSE;
-            text->selection_start_pos = -1;
-            text->selection_end_pos = -1;
-            if(event->keyval == GDK_Tab)
+            if(event->keyval == GDK_Tab && !control_state && !shift_state)
             {
 #ifdef WITH_PYTHON
                if(!file_emit_scripting_signal("tab-pressed", gds_file))
                {
 #endif
+                  gtk_extext_freeze(text);
+                  gtk_extext_delete_text(text, start, end);
+                  text->has_selection = FALSE;
+                  text->selection_start_pos = -1;
+                  text->selection_end_pos = -1;
                   spaces = make_spaces_string(tabstop);
                   if((gds_file->props.over_ride && gds_file->props.use_spaces) || (!gds_file->props.over_ride && global_spaces))
                      gtk_extext_insert_text(text, spaces, strlen(spaces), &start);
                   else
                      gtk_extext_insert_text(text, "\t", 1, &start);
                   g_free(spaces);
+                  gtk_extext_thaw(text);
+                  handled = TRUE;
 #ifdef WITH_PYTHON
                }
 #endif
             }
-            else
+            else if(event->keyval == ' ' && !control_state && !shift_state)
             {
+               gtk_extext_freeze(text);
+               gtk_extext_delete_text(text, start, end);
+               text->has_selection = FALSE;
+               text->selection_start_pos = -1;
+               text->selection_end_pos = -1;
                gtk_extext_insert_text(text, " ", 1, &start);
+               gtk_extext_thaw(text);
+               handled = TRUE;
             }
-            gtk_extext_thaw(text);
-            gtk_signal_emit_stop_by_name(GTK_OBJECT(widget), "key_press_event");
-            return(TRUE);
          }
-         gtk_extext_freeze(text);
-         text->has_selection = FALSE;
-         text->selection_start_pos = -1;
-         text->selection_end_pos = -1;
-         tabstop = text->default_tab_width;
-         spaces = make_spaces_string(tabstop);
-         while(current_line <= last_line)
-         {
-            gtk_extext_set_column(text, 0);
-            gtk_extext_set_line(text, current_line);
-            chars = gtk_extext_get_chars(text, text->current_pos, text->current_pos + text->default_tab_width);
-            if(event->keyval == GDK_Tab && control_state)
-            {
-               if(chars && !strcmp(chars, spaces))
-                  gtk_extext_delete_text(text, text->current_pos, text->current_pos + text->default_tab_width);
-               else if(chars && chars[0] == '\t')
-                  gtk_extext_delete_text(text, text->current_pos, text->current_pos + 1);
-            }
-            else if(event->keyval == GDK_Tab)
-            {
-               if((gds_file->props.over_ride && gds_file->props.use_spaces) || (!gds_file->props.over_ride && global_spaces))
-                  gtk_extext_insert_text(text, spaces, strlen(spaces), &text->current_pos);
-               else
-                  gtk_extext_insert_text(text, "\t", 1, &text->current_pos);
-            }
-            else if(event->keyval == ' ' && (control_state || shift_state))
-            {
-               if(chars[0] == ' ')
-                  gtk_extext_delete_text(text, text->current_pos, text->current_pos + 1);
-            }
-            else if(event->keyval == GDK_Delete && control_state)
-            {
-               gtk_extext_delete_text(text, text->current_pos, text->current_pos + 1);
-            }
-            else if(event->keyval == ' ')
-            {
-               gtk_extext_insert_text(text, " ", 1, &text->current_pos);
-            }
-            g_free(chars);
-            current_line++;
-         }
-         lineptr = gtk_extext_get_line_data(text, first_line, NULL);
-         start = lineptr->startpos;
-         g_free(lineptr);
-         lineptr = gtk_extext_get_line_data(text, last_line, NULL);
-         if(GTK_EXTEXT_INDEX(text, lineptr->endpos) == '\n')
-            end = lineptr->endpos-1;
          else
-            end = lineptr->endpos;
-         g_free(lineptr);
-         gtk_extext_set_position(text, end);
-         gtk_extext_thaw(text);
-         gtk_extext_select_region(text, start, end);
-         g_free(spaces);
-         handled = TRUE;
+         {
+            gtk_extext_freeze(text);
+            text->has_selection = FALSE;
+            text->selection_start_pos = -1;
+            text->selection_end_pos = -1;
+            tabstop = text->default_tab_width;
+            spaces = make_spaces_string(tabstop);
+            while(current_line <= last_line)
+            {
+               gtk_extext_set_column(text, 0);
+               gtk_extext_set_line(text, current_line);
+               chars = gtk_extext_get_chars(text, text->current_pos, text->current_pos + text->default_tab_width);
+               if(event->keyval == GDK_Tab && (control_state || shift_state))
+               {
+                  g_print("Blah, blah, blah, here we are!\n");
+                  if(chars && !strcmp(chars, spaces))
+                     gtk_extext_delete_text(text, text->current_pos, text->current_pos + text->default_tab_width);
+                  else if(chars && chars[0] == '\t')
+                     gtk_extext_delete_text(text, text->current_pos, text->current_pos + 1);
+               }
+               else if(event->keyval == GDK_Tab)
+               {
+                  if((gds_file->props.over_ride && gds_file->props.use_spaces) || (!gds_file->props.over_ride && global_spaces))
+                     gtk_extext_insert_text(text, spaces, strlen(spaces), &text->current_pos);
+                  else
+                     gtk_extext_insert_text(text, "\t", 1, &text->current_pos);
+               }
+               else if(event->keyval == ' ' && (control_state || shift_state))
+               {
+                  if(chars[0] == ' ')
+                     gtk_extext_delete_text(text, text->current_pos, text->current_pos + 1);
+               }
+               else if(event->keyval == GDK_Delete && control_state)
+               {
+                  gtk_extext_delete_text(text, text->current_pos, text->current_pos + 1);
+               }
+               else if(event->keyval == ' ')
+               {
+                  gtk_extext_insert_text(text, " ", 1, &text->current_pos);
+               }
+               g_free(chars);
+               current_line++;
+            }
+            lineptr = gtk_extext_get_line_data(text, first_line, NULL);
+            start = lineptr->startpos;
+            g_free(lineptr);
+            lineptr = gtk_extext_get_line_data(text, last_line, NULL);
+            if(GTK_EXTEXT_INDEX(text, lineptr->endpos) == '\n')
+               end = lineptr->endpos-1;
+            else
+               end = lineptr->endpos;
+            g_free(lineptr);
+            gtk_extext_set_position(text, end);
+            gtk_extext_thaw(text);
+            gtk_extext_select_region(text, start, end);
+            g_free(spaces);
+            handled = TRUE;
+         }
       }
+#ifdef WITH_PYTHON
+      else if(event->keyval == GDK_Tab && (control_state || shift_state))
+      {
+         handled = file_emit_scripting_signal("anti-tab-pressed", gds_file);
+      }
+#endif
       else if(event->keyval == GDK_Tab)
       {
 #ifdef WITH_PYTHON
@@ -414,6 +464,10 @@ static gint key_press_cb(GtkWidget *widget, GdkEventKey *event, GdsFile *gds_fil
       }
    }
    if(handled) gtk_signal_emit_stop_by_name(GTK_OBJECT(widget), "key_press_event");
+#ifdef WITH_PYTHON
+   else if(key > 0 && key <= 127 && gds_file->tables && gds_file->tables->key_pressed_callback)
+      call_scripting_function_extended(gds_file->tables->key_pressed_callback, control_state ? TRUE : FALSE, shift_state ? TRUE : FALSE, alt_state ? TRUE : FALSE, key, curpos);
+#endif
    return(handled);
 }
 
@@ -538,3 +592,42 @@ void gds_file_set_global_props(gint undo, gint spaces, gboolean indent, gboolean
    global_bracketmatch = bracket;
    global_tab_stops = tab_stops;
 }
+
+gchar *gds_file_display_filename(GnomeVFSURI *uri, gboolean full)
+{
+   gchar *filename;
+   if(full)
+     filename = (gchar *)gnome_vfs_uri_get_path(uri);
+   else
+     filename = (gchar *)gnome_vfs_uri_get_basename(uri);
+   filename = gnome_vfs_unescape_string(filename, "/");
+   return(filename);
+}
+
+gchar *gds_file_get_path(GdsFile *file)
+{
+   gchar *path;
+   path = (gchar *)gnome_vfs_uri_extract_dirname(file->uri);
+   return(path);
+}
+
+gchar *gds_file_get_filename(GdsFile *file)
+{
+   gchar *filename;
+   filename = gnome_vfs_uri_extract_short_name(file->uri);
+   return(filename);
+}
+
+gchar *gds_file_get_filename_nix_extension(GdsFile *file)
+{
+   gchar *filename;
+   gchar *extension;
+   gchar *retval;
+
+   filename = gnome_vfs_uri_extract_short_name(file->uri);
+   extension = strrchr(filename, '.');
+   if(extension) { *extension = '\0'; }
+   retval =  g_strdup(filename);
+   g_free(filename);
+   return(retval);
+}
