@@ -1,32 +1,31 @@
-/* Glimmer - gdsfile.h
-*  
-*  File Widget (MDI entry, text widget etc.)
-*  Copyright 2000 by Chris Phelps
-*  
-*  This program is free software; you can redistribute it and/or modify
-*  it under the terms of the GNU General Public License as published by
-*  the Free Software Foundation; either version 2 of the License, or
-*  (at your option) any later version.
-*
-*  This program is distributed in the hope that it will be useful,
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-*  GNU Library General Public License for more details.
-*
-*  You should have received a copy of the GNU Library General Public License
-*  along with this program; if not, write to the Free Software
-*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-*/
+/*  Glimmer - gdsfile.h
+ *  This library is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU Library General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ */
 
+#include <libgnomevfs/gnome-vfs-types.h>
+#include <libgnomevfs/gnome-vfs-uri.h>
 
-#ifndef _GDS_FILE_H__
-#define _GDS_FILE_H__
+#include <gnome.h>
+#include <time.h>
+
+#ifndef _GDS_FILE_H_
+#define _GDS_FILE_H_
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-#include <gnome.h>
-#include <time.h>
 #include "../declarations.h"
 #include "gdseditor.h"
 
@@ -55,9 +54,9 @@ typedef struct _highlight_table
    gchar *filename;
    GList *extensions;
    GList *mime_types;
-   GdsEditorHighlightTable *syntax;
-   GdsEditorHighlightTable *pattern;
-   GdsEditorHighlightTable *embedded;
+   GtkExTextHighlightTable *syntax;
+   GtkExTextHighlightTable *pattern;
+   GtkExTextHighlightTable *embedded;
    GdsFileProperties props;
 
 #ifdef WITH_PYTHON
@@ -76,6 +75,7 @@ typedef struct _highlight_table
    gpointer enter_pressed_callback;
    gpointer tab_pressed_callback;
    gpointer anti_tab_pressed_callback;
+   gpointer key_pressed_callback;
    /* Callbacks for certain build events */
    gpointer compile_hook;
    gpointer stop_compile_hook;
@@ -97,7 +97,9 @@ typedef struct _GdsFileClass GdsFileClass;
 struct _GdsFile
 {
    GtkHBox box;
+   GtkWidget *pixmap;
    GtkWidget *menu_item;
+   GtkWidget *nb_label;
    GtkWidget *tear_away;
    GtkWidget *text;
    GtkWidget *vscroller;
@@ -105,7 +107,11 @@ struct _GdsFile
    GtkWidget *file_data;
    GtkWidget *script_box;
    GtkWidget *props_dialog; // NULL unless there is a props dialog
+   GnomeVFSURI *uri;
    gchar *filename;
+   gboolean need_pass;
+   gpointer storage;
+   gboolean xfering;
    gboolean changed_set;
    gboolean default_lang;
    time_t modtime;
@@ -114,6 +120,11 @@ struct _GdsFile
    gint debug_pid;
    gint exec_pid;
    GdsFileProperties props;
+   // Widget that tells us what is going on
+   GtkWidget *xferprogress;
+   // Function to call when we finish an async xfer to finish the update
+   GtkSignalFunc xfer_finish;
+   gpointer xfer_data;
 };
 
 struct _GdsFileClass
@@ -123,12 +134,15 @@ struct _GdsFileClass
 
 GtkType gds_file_get_type(void);
 
-GtkWidget *gds_file_new(gchar *filename, gboolean full);
-void gds_file_set_filename(GdsFile *gds_file, gchar *filename);
-void gds_file_set_title(GdsFile *gds_file, gchar *title, gboolean full);
+GtkWidget *gds_file_new(GnomeVFSURI *uri, gboolean full);
+void gds_file_set_uri(GdsFile *gds_file, GnomeVFSURI *uri, gboolean full);
+void gds_file_set_title(GdsFile *gds_file, gboolean full);
 gboolean find_bracket_match(GtkWidget *widget, gint *search);
 void gds_file_set_global_props(gint undo, gint spaces, gboolean indent, gboolean bracket, gboolean tab_stops);
-
+gchar *gds_file_display_filename(GnomeVFSURI *uri, gboolean full);
+gchar *gds_file_get_path(GdsFile *file);
+gchar *gds_file_get_filename(GdsFile *file);
+gchar *gds_file_get_filename_nix_extension(GdsFile *file);
 #ifdef __cplusplus /* cpp compatibility */
 }
 #endif
