@@ -1,6 +1,22 @@
+/*  Glimmer - gnomedirlist.c
+ *  This library is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU Library General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ */
+
 #include "gnomedirlist.h"
-#include "../xpm/folder_closed.xpm"
-#include "../xpm/folder_open.xpm"
+#include "xpm/folder_closed.xpm"
+#include "xpm/folder_open.xpm"
 
 /* function declarations */
 static void gnome_dirlist_class_init(GnomeDirListClass *_class);
