@@ -1,4 +1,4 @@
-/*  windows.h
+/*  Glimmer - windows.h
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -7,7 +7,7 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
@@ -21,12 +21,21 @@
 extern "C" {
 #endif
 
+#include "declarations.h"
+
 void new_window_cb(GtkWidget *widget, gpointer data);
 void cycle_left_cb(GtkWidget *widget, gpointer data);
 void cycle_right_cb(GtkWidget *widget, gpointer data);
 void move_left_cb(GtkWidget *widget, gpointer data);
 void move_right_cb(GtkWidget *widget, gpointer data);
 
+#ifdef WITH_PYTHON
+void cycle_left_paned_cb(GtkWidget *widget, gpointer data);
+void cycle_right_paned_cb(GtkWidget *widget, gpointer data);
+void focus_current_file_cb(GtkWidget *widget, gpointer data);
+void focus_current_paned_cb(GtkWidget *widget, gpointer data);
+#endif
+
 #ifdef __cplusplus
 }
 #endif
